<!DOCTYPE html>
<html>

<!-- Mirrored from html.yogsthemes.com/demo/banqix/index-3.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:00:09 GMT -->
<head>
<meta charset="utf-8">
<title>Banqix TV & Internet Business HTML-5 Template | Homepage 03</title>
<!-- Stylesheets -->
<link href="assets/css/bootstrap.css" rel="stylesheet">
<link href="assets/css/style.css" rel="stylesheet">
<link href="assets/css/meanmenu.min.css" rel="stylesheet">
<link href="assets/css/responsive.css" rel="stylesheet">

<!-- Color Switcher Mockup -->
<link href="assets/css/color-switcher-design.css" rel="stylesheet">

<!-- Color Themes -->
<link id="theme-color-file" href="assets/css/color-themes/default-color.css" rel="stylesheet">

<link href="https://fonts.googleapis.com/css2?family=Unbounded:wght@300;400;500;600;700;800;900&amp;display=swap" rel="stylesheet">
<link href="https://fonts.googleapis.com/css2?family=DM+Sans:opsz,wght@9..40,300;9..40,400;9..40,500;9..40,600;9..40,700;9..40,800;9..40,900&amp;display=swap" rel="stylesheet">

<link rel="shortcut icon" href="assets/images/favicon.png" type="image/x-icon">
<link rel="icon" href="assets/images/favicon.png" type="image/x-icon">

<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">

<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
</head>

<body>

<div class="page-wrapper">
	
	<!-- Cursor -->
	<div class="cursor"></div>
	<div class="cursor-follower"></div>
	<!-- Cursor End -->
 	
	<!-- Preloader -->
    <div class="preloader"></div>
	<!-- End Preloader -->
	
	<!-- Main Header / Header Three -->
	<header class="main-header header-style-three">
		<!-- Header Top Two -->
		<div class="header-top_two">
			<div class="auto-container">
				<div class="inner-container">
					<div class="d-flex justify-content-between align-items-center flex-wrap">
						<div class="left-box d-flex align-items-center flex-wrap">

							<!-- Header Three Socials -->
							<div class="header-three_socials">
								<a class="fa-brands fa-facebook-f fa-fw" href="#"></a>
								<a class="fa-brands fa-twitter fa-fw" href="#"></a>
								<a class="fa-brands fa-pinterest-p fa-fw" href="#"></a>
								<a class="fa-brands fa-instagram fa-fw" href="#"></a>
							</div>

							<!-- Info List -->
							<div class="header-top_navs d-flex flex-wrap">
								<a href="#">Residential Services</a>
								<a href="#">Business Services</a>
								<a href="#">TV & Streaming</a>
							</div>
						</div>
						
						<!-- Header Three Network -->
						<div class="header-three_network">Attend to our quize offer & win free network. <a href="#">Free Network</a></div>

					</div>
				</div>
			</div>
		</div>

		<!-- Header Upper -->
		<div class="header-upper">
			<div class="auto-container">
				<div class="inner-container">
					<div class="d-flex justify-content-between align-items-center flex-wrap">
						
						<div class="logo-box">
							<div class="logo"><a href="index.html"><img src="assets/images/logo-2.png" alt="" title=""></a></div>
						</div>
						
						<!-- Header Info Outer -->
						<div class="header-info_outer">
							<!-- Info Box -->
							<div class="header-info_box">
								<div class="header-info_box-inner">
									<span class="header-info_box-icon flaticon-map"></span>
									Our Location
									<strong>27/4 Barden, London</strong>
								</div>
							</div>
							<!-- Info Box -->
							<div class="header-info_box">
								<div class="header-info_box-inner">
									<span class="header-info_box-icon flaticon-email-1"></span>
									Online Support
									<strong>support@envato.com</strong>
								</div>
							</div>
							<!-- Info Box -->
							<div class="header-info_box">
								<div class="header-info_box-inner">
									<span class="header-info_box-icon flaticon-phone-call-2"></span>
									Free Contact
									<strong>02-3425-3342-52</strong>
								</div>
							</div>
						</div>

						<!-- Main Menu End-->
						<div class="outer-box d-flex align-items-center flex-wrap">
							<!-- Search Btn -->
							<div class="search-box-btn search-box-outer"><span class="icon fa fa-search"></span></div>							
						</div>
						
					</div>
				</div>
			</div>
		</div>
		<!-- End Header Upper -->
		
		<!-- Hedare Lower -->
		<div class="header-lower">
			<div class="auto-container">
				<div class="d-flex justify-content-end flex-wrap">

					<div class="logo"><a href="index.html"><img src="assets/images/logo.png" alt="" title=""></a></div>

					<!-- Nav Outer -->
					<div class="nav-outer">
						<!-- Main Menu -->
						<nav class="main-menu navbar-expand-md">
							<div class="navbar-header">
								<!-- Toggle Button -->    	
								<button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
									<span class="icon-bar"></span>
									<span class="icon-bar"></span>
									<span class="icon-bar"></span>
								</button>
							</div>
							
							<div class="navbar-collapse collapse clearfix" id="navbarSupportedContent">
								<ul class="navigation clearfix">
									<li class="dropdown"><a href="#">Home</a>
										<ul>
											<li><a href="index.html">Homepage 01</a></li>
											<li><a href="index-2.html">Homepage 02</a></li>
											<li><a href="index-3.html">Homepage 03</a></li>
											<li><a href="index-4.html">Homepage 04</a></li>
											<li class="dropdown"><a href="#">Header Styles</a>
												<ul>
													<li><a href="index.html">Header 01</a></li>
													<li><a href="index-2.html">Header 02</a></li>
													<li><a href="index-3.html">Header 03</a></li>
													<li><a href="index-4.html">Header 04</a></li>
												</ul>
											</li>
										</ul>
									</li>
									<li class="dropdown"><a href="#">About</a>
										<ul>
											<li><a href="about.html">About us</a></li>
											<li><a href="faq.html">Faq</a></li>
											<li><a href="price.html">price</a></li>
											<li><a href="privacy.html">Privacy Policy</a></li>
											<li><a href="terms.html">Terms & Condition</a></li>
											<li class="dropdown"><a href="#">Team</a>
												<ul>
													<li><a href="team.html">Team</a></li>
													<li><a href="team-detail.html">Team Detail</a></li>
												</ul>
											</li>
										</ul>
									</li>
									<li class="dropdown"><a href="#">service</a>
										<ul>
											<li><a href="services.html">Services</a></li>
											<li><a href="service-detail.html">service detail</a></li>
										</ul>
									</li>
									<li class="dropdown"><a href="#">shop</a>
										<ul>
											<li><a href="shop.html">shop</a></li>
											<li><a href="shop-detail.html">shop detail</a></li>
											<li><a href="coming-soon.html">coming soon</a></li>
										</ul>
									</li>
									<li class="dropdown"><a href="#">Blog</a>
										<ul>
											<li><a href="blog.html">Our Blog</a></li>
											<li><a href="blog-detail.html">Blog Detail</a></li>
											<li><a href="not-found.html">Not Found</a></li>
										</ul>
									</li>
									<li><a href="contact.html">Contact</a></li>
								</ul>
							</div>
						</nav>
					</div>

					<!-- Options Box -->
					<div class="options-box d-flex align-items-center flex-wrap">
						<!-- Login Box -->
						<a class="header-login_box" href="#">
							<i class="fa-regular fa-user fa-fw"></i>
						</a>

						<!-- Nav Btn -->
						<div class="nav-btn navSidebar-button">
							<i class="fas fa-shopping-cart fa-fw"></i>
							<span>2</span>
						</div>

						<!-- Mobile Navigation Toggler -->
						<div class="mobile-nav-toggler"><span class="icon flaticon-menu"></span></div>

					</div>

				</div>
			</div>
		</div>

		<!-- Mobile Menu  -->
		<div class="mobile-menu">
			<div class="menu-backdrop"></div>
			<div class="close-btn"><span class="icon flaticon-multiply"></span></div>
			
			<nav class="menu-box">
				<div class="nav-logo"><a href="index.html"><img src="assets/images/logo.png" alt="" title=""></a></div>
				<div class="menu-outer"><!--Here Menu Will Come Automatically Via Javascript / Same Menu as in Header--></div>
			</nav>
		</div>
		<!-- End Mobile Menu -->
	
	</header>
	<!-- End Main Header -->
	
	<!-- Sidebar Cart Item -->
	<div class="xs-sidebar-group info-group">
		<div class="xs-overlay xs-bg-black"></div>
		<div class="xs-sidebar-widget">
			<div class="sidebar-widget-container">
				<div class="close-button">
					<span class="fa-solid fa-xmark fa-fw"></span>
				</div>
				<div class="sidebar-textwidget">
					
					<!-- Sidebar Info Content -->
					<div class="sidebar-info-contents">
						<div class="content-inner">
						
							<!-- Title Box -->
							<div class="title-box">
								<h5>Broadband <span>connection</span></h5>
								<div class="price">$15 from free economy shipping</div>
							</div>
							
							<!-- Empty Cart Box -->
							<div class="empty-cart-box">
								<!-- No Product -->
								<div class="no-cart">
									<span class="icon fa-solid fa-cart-flatbed-suitcase fa-fw"></span>
									No products in cart.
								</div>
							</div>
							
							<!-- Lower Box -->
							<div class="lower-box">
								<h5>Popular <span>Suggestions</span></h5>
									
								<!-- Post Block -->
								<div class="post-block">
									<div class="inner-box">
										<div class="image">
											<img src="assets/images/resource/post-thumb-1.jpg" alt="" />
										</div>
										<h6><a href="#">Free Installation</a></h6>
										<div class="rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
										</div>
										<div class="price-box">$125</div>
										<a class="theme-btn bag-btn" href="#">add to bag</a>
									</div>
								</div>
								
								<!-- Post Block -->
								<div class="post-block">
									<div class="inner-box">
										<div class="image">
											<img src="assets/images/resource/post-thumb-2.jpg" alt="" />
										</div>
										<h6><a href="#">Ultra Fast Connect</a></h6>
										<div class="rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
										</div>
										<div class="price-box">$205</div>
										<a class="theme-btn bag-btn" href="#">add to bag</a>
									</div>
								</div>
								
								<!-- Post Block -->
								<div class="post-block">
									<div class="inner-box">
										<div class="image">
											<img src="assets/images/resource/post-thumb-3.jpg" alt="" />
										</div>
										<h6><a href="#">4K and 8K Quality</a></h6>
										<div class="rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
										</div>
										<div class="price-box">$25</div>
										<a class="theme-btn bag-btn" href="#">add to bag</a>
									</div>
								</div>
								
							</div>
							
						</div>
					</div>
					
				</div>
			</div>
		</div>
	</div>

	<!-- Slider Three -->
	<section class="slider-three">
		<div class="main-slider swiper-container">
			<div class="swiper-wrapper">

				<!-- Slide -->
				<div class="swiper-slide">
					<div class="slider-three_image-one" style="background-image:url(assets/images/main-slider/8.jpg)"></div>
					<div class="slider-three_image-two" style="background-image:url(assets/images/main-slider/9.jpg)"></div>
					<div class="auto-container">
						<div class="row clearfix">
							<!-- Content Column -->
							<div class="slider-three_image-column col-lg-5 col-md-12 col-sm-12">
								<div class="slider-three_image-outer">
									<div class="slider-three_image">
										<img src="assets/images/main-slider/image-1.png" alt="" />
										<div class="slider-three_price" style="background-image:url(assets/images/main-slider/price-pattern.png)">
											$12 <span>Per Month</span>
										</div>
									</div>
								</div>
							</div>
							<!-- Content Column -->
							<div class="slider-three_content-column col-lg-7 col-md-12 col-sm-12">
								<div class="slider-three_content-inner">
									<div class="slider-three_title">Unbeatable Internet</div>
									<h1 class="slider-three_heading">Enjoy high <br> Speed Broad-band</h1>
									<div class="slider-three_text">Ongoing advancements, such as the deployment of 5G networks and the expansion of fiber-optic of infrastructure</div>
								</div>
							</div>
						</div>
						
					</div>
				</div>

				<!-- Slide -->
				<div class="swiper-slide">
					<div class="slider-three_image-one" style="background-image:url(assets/images/main-slider/8.jpg)"></div>
					<div class="slider-three_image-two" style="background-image:url(assets/images/main-slider/9.jpg)"></div>
					<div class="auto-container">
						<div class="row clearfix">
							<!-- Content Column -->
							<div class="slider-three_image-column col-lg-5 col-md-12 col-sm-12">
								<div class="slider-three_image-outer">
									<div class="slider-three_image">
										<img src="assets/images/main-slider/image-1.png" alt="" />
										<div class="slider-three_price" style="background-image:url(assets/images/main-slider/price-pattern.png)">
											$12 <span>Per Month</span>
										</div>
									</div>
								</div>
							</div>
							<!-- Content Column -->
							<div class="slider-three_content-column col-lg-7 col-md-12 col-sm-12">
								<div class="slider-three_content-inner">
									<div class="slider-three_title">Unbeatable Internet</div>
									<h1 class="slider-three_heading">Enjoy high <br> Speed Broad-band</h1>
									<div class="slider-three_text">Ongoing advancements, such as the deployment of 5G networks and the expansion of fiber-optic of infrastructure</div>
								</div>
							</div>
						</div>
						
					</div>
				</div>

				<!-- Slide -->
				<div class="swiper-slide">
					<div class="slider-three_image-one" style="background-image:url(assets/images/main-slider/8.jpg)"></div>
					<div class="slider-three_image-two" style="background-image:url(assets/images/main-slider/9.jpg)"></div>
					<div class="auto-container">
						<div class="row clearfix">
							<!-- Content Column -->
							<div class="slider-three_image-column col-lg-5 col-md-12 col-sm-12">
								<div class="slider-three_image-outer">
									<div class="slider-three_image">
										<img src="assets/images/main-slider/image-1.png" alt="" />
										<div class="slider-three_price" style="background-image:url(assets/images/main-slider/price-pattern.png)">
											$12 <span>Per Month</span>
										</div>
									</div>
								</div>
							</div>
							<!-- Content Column -->
							<div class="slider-three_content-column col-lg-7 col-md-12 col-sm-12">
								<div class="slider-three_content-inner">
									<div class="slider-three_title">Unbeatable Internet</div>
									<h1 class="slider-three_heading">Enjoy high <br> Speed Broad-band</h1>
									<div class="slider-three_text">Ongoing advancements, such as the deployment of 5G networks and the expansion of fiber-optic of infrastructure</div>
								</div>
							</div>
						</div>
						
					</div>
				</div>

			</div>
		</div>
	</section>
	<!-- End Slider Three -->

	<!-- Services Four -->
	<section class="services-four">
		<div class="auto-container_two">
			<div class="row clearfix">

				<!-- Service Block Three -->
				<div class="service-block_three col-lg-4 col-md-6 col-sm-12">
					<div class="service-block_three-inner wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
						<div class="service-block_three-icon">
							<i class="flaticon-tower"></i>
						</div>
						<div class="service-block_three-content">
							<div class="service-block_three-image" style="background-image:url(assets/images/resource/service-5.jpg)"></div>
							<h4 class="service-block_three-heading"><a href="service-detail.html">Corporates Internet</a></h4>
							<ul class="service-block_three-list">
								<li><i class="fa-solid fa-angles-right fa-fw"></i>24x7 Support</li>
								<li><i class="fa-solid fa-angles-right fa-fw"></i>Business-friendly SLAs</li>
								<li><i class="fa-solid fa-angles-right fa-fw"></i>Dedicated Network</li>
							</ul>
						</div>
					</div>
				</div>

				<!-- Service Block Three -->
				<div class="service-block_three col-lg-4 col-md-6 col-sm-12">
					<div class="service-block_three-inner wow fadeInUp" data-wow-delay="0ms" data-wow-duration="1500ms">
						<div class="service-block_three-icon">
							<i class="flaticon-technology"></i>
						</div>
						<div class="service-block_three-content">
							<div class="service-block_three-image" style="background-image:url(assets/images/resource/service-5.jpg)"></div>
							<h4 class="service-block_three-heading"><a href="service-detail.html">Home <br> Internet</a></h4>
							<ul class="service-block_three-list">
								<li><i class="fa-solid fa-angles-right fa-fw"></i>Lag free Gaming</li>
								<li><i class="fa-solid fa-angles-right fa-fw"></i>Bufferless Steaming</li>
								<li><i class="fa-solid fa-angles-right fa-fw"></i>Real Ip Included</li>
							</ul>
						</div>
					</div>
				</div>

				<!-- Service Block Three -->
				<div class="service-block_three col-lg-4 col-md-6 col-sm-12">
					<div class="service-block_three-inner wow fadeInRight" data-wow-delay="0ms" data-wow-duration="1500ms">
						<div class="service-block_three-icon">
							<i class="flaticon-globe-grid"></i>
						</div>
						<div class="service-block_three-content">
							<div class="service-block_three-image" style="background-image:url(assets/images/resource/service-5.jpg)"></div>
							<h4 class="service-block_three-heading"><a href="service-detail.html">Data Connectivity</a></h4>
							<ul class="service-block_three-list">
								<li><i class="fa-solid fa-angles-right fa-fw"></i>Optical Fiber Network</li>
								<li><i class="fa-solid fa-angles-right fa-fw"></i>World Class Reliability</li>
								<li><i class="fa-solid fa-angles-right fa-fw"></i>Optimal performance</li>
							</ul>
						</div>
					</div>
				</div>

			</div>
		</div>
	</section>
	<!-- End Services Four -->

	<!-- About Three -->
	<section class="about-three">
		<!-- Avatar Three Icon -->
		<div class="about-three_avatar-one" data-parallax='{"x" : 60}'>
			<img src="assets/images/icons/about-1.png" alt="" />
		</div>
		<div class="auto-container_two">
			<div class="row clearfix">
				
				<!-- Content Column -->
				<div class="about-three_content-column col-lg-6 col-md-12 col-sm-12">
					<div class="about-three_content-outer">
						<!-- Sec Title -->
						<div class="sec-title title-anim">
							<div class="sec-title_title">About Our Internet</div>
							<h2 class="sec-title_heading">Provide Best Internet Services</h2>
						</div>

						<!-- About Three Tabs -->
						<div class="about-three_tabs">
							<!-- Product Tabs -->
							<div class="about-three_tab tabs-box">
							
								<!-- Tab Btns -->
								<ul class="tab-btns tab-buttons clearfix">
									<li data-tab="#prod-info" class="tab-btn active-btn">Services we Provide</li>
									<li data-tab="#prod-review" class="tab-btn">Care Value</li>
								</ul>
								
								<!-- Tabs Container -->
								<div class="tabs-content">
									
									<!-- Tab -->
									<div class="tab active-tab" id="prod-info">
										<div class="content">
											<div class="about-three_text">Ongoing advancements, such as the deployment of 5G network & the expansion of fiber-optic infrastructure, aim to improve the speeds and reliability of broadband services.Consumers should consider their..</div>
											<div class="about-three_block">
												<div class="about-three_block-inner">
													<div class="about-three_block-icon">
														<i class="flaticon-wifi-2"></i>
													</div>
													<h6 class="about-three_block-heading">Free wifi router included</h6>
													Consumers should consider their specific needs, <br> including speed requirements.
												</div>
											</div>
										</div>
									</div>

									<!-- Tab -->
									<div class="tab" id="prod-review">
										<div class="content">
											<div class="about-three_text">Ongoing advancements, such as the deployment of 5G network & the expansion of fiber-optic infrastructure, aim to improve the speeds and reliability of broadband services.Consumers should consider their..</div>
											<div class="about-three_block">
												<div class="about-three_block-inner">
													<div class="about-three_block-icon">
														<i class="flaticon-wifi-2"></i>
													</div>
													<h6 class="about-three_block-heading">Free wifi router included</h6>
													Consumers should consider their specific needs, <br> including speed requirements.
												</div>
											</div>
										</div>
									</div>

								</div>
							</div>
						</div>

					</div>
				</div>

				<!-- Map Column -->
				<div class="about-three_map-column col-lg-6 col-md-12 col-sm-12">
					<div class="about-three_map-outer">
						<div class="about-three_counter">
							<div class="about-three_map-arrow" style="background-image:url(assets/images/icons/arrow.png)"></div>
							<div class="about-three_count"><span class="odometer" data-count="500"></span> <i>K+</i></div>
							<div class="about-three_counter-text">Clients Trusted Us</div>
						</div>
						<div class="about-three_map">
							<img src="assets/images/background/map.png" alt="" />
						</div>
					</div>
				</div>

			</div>
		</div>
	</section>
	<!-- End About Three -->

	<!-- Services Five -->
	<section class="services-five">
		<div class="auto-container">
			<div class="row clearfix">
				
				<!-- Content Column -->
				<div class="services-five_title-column col-lg-4 col-md-12 col-sm-12">
					<div class="services-five_title-outer">
						<div class="services-five_title-bg" style="background-image:url(assets/images/resource/service-five.jpg)"></div>
						<!-- Sec Title -->
						<div class="sec-title light title-anim">
							<div class="sec-title_title">Our Services</div>
							<h2 class="sec-title_heading">Explores Our Services</h2>
							<div class="sec-title_text">Some providers impose data caps, limiting the amount of data users</div>
						</div>
						<!-- If we need navigation buttons -->
						<div class="services-five_carousel-prev fas fa-arrow-left fa-fw"></div>
						<div class="services-five_carousel-next fas fa-arrow-right fa-fw"></div>
					</div>
				</div>

				<!-- Blocks Column -->
				<div class="services-five_blocks-column col-lg-8 col-md-12 col-sm-12">
					<div class="services-five_blocks-outer">
						<div class="services-five_carousel swiper-container">
							<div class="swiper-wrapper">
				
								<!-- Slide -->
								<div class="swiper-slide">
									<!-- Service Block Four -->
									<div class="service-block_four">
										<div class="service-block_four-inner">
											<div class="service-block_four-upper">
												<div class="service-block_four-content">
													<div class="service-block_four-off">Super 45 Off</div>
													<h4 class="service-block_four-heading"><a href="service-detail.html">Strongers wifi</a></h4>
												</div>
												<div class="service-block_four-text">Rural and remotes areas may have limited access to broadband services.</div>
												<div class="service-block_four-icon">
													<i class="flaticon-globe-grid"></i>
												</div>
											</div>
											<div class="service-block_four-image">
												<a href="service-detail.html"><img src="assets/images/resource/service-6.jpg" alt="" /></a>
												<a href="service-detail.html" class="service-block_four-arrow fas fa-arrow-right fa-fw"></a>
											</div>
										</div>
									</div>
								</div>
								<!-- Slide -->
								<div class="swiper-slide">
									<!-- Service Block Four -->
									<div class="service-block_four">
										<div class="service-block_four-inner">
											<div class="service-block_four-upper">
												<div class="service-block_four-content">
													<div class="service-block_four-off">Super 45 Off</div>
													<h4 class="service-block_four-heading"><a href="service-detail.html">Strongers wifi</a></h4>
												</div>
												<div class="service-block_four-text">Rural and remotes areas may have limited access to broadband services.</div>
												<div class="service-block_four-icon">
													<i class="flaticon-traffic-data"></i>
												</div>
											</div>
											<div class="service-block_four-image">
												<a href="service-detail.html"><img src="assets/images/resource/service-7.jpg" alt="" /></a>
												<a href="service-detail.html" class="service-block_four-arrow fas fa-arrow-right fa-fw"></a>
											</div>
										</div>
									</div>
								</div>
								<!-- Slide -->
								<div class="swiper-slide">
									<!-- Service Block Four -->
									<div class="service-block_four">
										<div class="service-block_four-inner">
											<div class="service-block_four-upper">
												<div class="service-block_four-content">
													<div class="service-block_four-off">Super 45 Off</div>
													<h4 class="service-block_four-heading"><a href="service-detail.html">Strongers wifi</a></h4>
												</div>
												<div class="service-block_four-text">Rural and remotes areas may have limited access to broadband services.</div>
												<div class="service-block_four-icon">
													<i class="flaticon-live"></i>
												</div>
											</div>
											<div class="service-block_four-image">
												<a href="service-detail.html"><img src="assets/images/resource/service-7.jpg" alt="" /></a>
												<a href="service-detail.html" class="service-block_four-arrow fas fa-arrow-right fa-fw"></a>
											</div>
										</div>
									</div>
								</div>
								<!-- Slide -->
								<div class="swiper-slide">
									<!-- Service Block Four -->
									<div class="service-block_four">
										<div class="service-block_four-inner">
											<div class="service-block_four-upper">
												<div class="service-block_four-content">
													<div class="service-block_four-off">Super 45 Off</div>
													<h4 class="service-block_four-heading"><a href="service-detail.html">Strongers wifi</a></h4>
												</div>
												<div class="service-block_four-text">Rural and remotes areas may have limited access to broadband services.</div>
												<div class="service-block_four-icon">
													<i class="flaticon-wifi-router"></i>
												</div>
											</div>
											<div class="service-block_four-image">
												<a href="service-detail.html"><img src="assets/images/resource/service-8.jpg" alt="" /></a>
												<a href="service-detail.html" class="service-block_four-arrow fas fa-arrow-right fa-fw"></a>
											</div>
										</div>
									</div>
								</div>

							</div>

						</div>
					</div>
				</div>

			</div>
		</div>
	</section>
	<!-- End Services Five -->

	<!-- Products One -->
	<section class="products-one">
		<div class="auto-container">
			<div class="inner-container">
				<!-- Sec Title -->
				<div class="sec-title title-anim centered">
					<div class="sec-title_title">Popular Product</div>
					<h2 class="sec-title_heading">Our Popular Product</h2>
				</div>
				<div class="row clearfix">

					<!-- Product Block Two -->
					<div class="products-block_two col-lg-3 col-md-6 col-sm-6">
						<div class="products-block_two-inner wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
							<!-- Upper Box -->
							<div class="products-block_two-upper">
								<div class="d-flex justify-content-between align-items-center flex-wrap">
									<a class="products-block_two-cart" href="shop-detail.html">Add To Cart</a>
									<ul class="products-block_two-options">
										<li><a class="fa-regular fa-eye fa-fw" href="shop-detail.html"></a></li>
										<li><a class="fa-regular fa-heart fa-fw" href="shop-detail.html"></a></li>
									</ul>
								</div>
							</div>
							<!-- Content Box -->
							<div class="products-block_two-content">
								<div class="products-block_two-price">$37.00</div>
								<h4 class="products-block_two-title"><a href="shop-detail.html">wireless-router</a></h4>
								<div class="products-block_two-rating">
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
								</div>
							</div>
							<div class="products-block_two-image">
								<span><img src="assets/images/resource/products/5.png" alt="" /></span>
							</div>
							<div class="products-block_two-icon" style="background-image:url(assets/images/icons/product-two_circle.png)"></div>
						</div>
					</div>

					<!-- Product Block Two -->
					<div class="products-block_two col-lg-3 col-md-6 col-sm-6">
						<div class="products-block_two-inner wow fadeInLeft" data-wow-delay="150ms" data-wow-duration="1500ms">
							<!-- Upper Box -->
							<div class="products-block_two-upper">
								<div class="d-flex justify-content-between align-items-center flex-wrap">
									<a class="products-block_two-cart" href="shop-detail.html">Add To Cart</a>
									<ul class="products-block_two-options">
										<li><a class="fa-regular fa-eye fa-fw" href="shop-detail.html"></a></li>
										<li><a class="fa-regular fa-heart fa-fw" href="shop-detail.html"></a></li>
									</ul>
								</div>
							</div>
							<!-- Content Box -->
							<div class="products-block_two-content">
								<div class="products-block_two-price">$70.00</div>
								<h4 class="products-block_two-title"><a href="shop-detail.html">Speedometer</a></h4>
								<div class="products-block_two-rating">
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
								</div>
							</div>
							<div class="products-block_two-image">
								<span><img src="assets/images/resource/products/6.png" alt="" /></span>
							</div>
							<div class="products-block_two-icon" style="background-image:url(assets/images/icons/product-two_circle.png)"></div>
						</div>
					</div>

					<!-- Product Block Two -->
					<div class="products-block_two col-lg-3 col-md-6 col-sm-6">
						<div class="products-block_two-inner wow fadeInLeft" data-wow-delay="300ms" data-wow-duration="1500ms">
							<!-- Upper Box -->
							<div class="products-block_two-upper">
								<div class="d-flex justify-content-between align-items-center flex-wrap">
									<a class="products-block_two-cart" href="shop-detail.html">Add To Cart</a>
									<ul class="products-block_two-options">
										<li><a class="fa-regular fa-eye fa-fw" href="shop-detail.html"></a></li>
										<li><a class="fa-regular fa-heart fa-fw" href="shop-detail.html"></a></li>
									</ul>
								</div>
							</div>
							<!-- Content Box -->
							<div class="products-block_two-content">
								<div class="products-block_two-price">$15.00</div>
								<h4 class="products-block_two-title"><a href="shop-detail.html">Ethernet</a></h4>
								<div class="products-block_two-rating">
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
								</div>
							</div>
							<div class="products-block_two-image">
								<span><img src="assets/images/resource/products/7.png" alt="" /></span>
							</div>
							<div class="products-block_two-icon" style="background-image:url(assets/images/icons/product-two_circle.png)"></div>
						</div>
					</div>

					<!-- Product Block Two -->
					<div class="products-block_two col-lg-3 col-md-6 col-sm-6">
						<div class="products-block_two-inner wow fadeInLeft" data-wow-delay="450ms" data-wow-duration="1500ms">
							<!-- Upper Box -->
							<div class="products-block_two-upper">
								<div class="d-flex justify-content-between align-items-center flex-wrap">
									<a class="products-block_two-cart" href="shop-detail.html">Add To Cart</a>
									<ul class="products-block_two-options">
										<li><a class="fa-regular fa-eye fa-fw" href="shop-detail.html"></a></li>
										<li><a class="fa-regular fa-heart fa-fw" href="shop-detail.html"></a></li>
									</ul>
								</div>
							</div>
							<!-- Content Box -->
							<div class="products-block_two-content">
								<div class="products-block_two-price">$60.00</div>
								<h4 class="products-block_two-title"><a href="shop-detail.html">Headphones</a></h4>
								<div class="products-block_two-rating">
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
									<span class="fa fa-star"></span>
								</div>
							</div>
							<div class="products-block_two-image">
								<span><img src="assets/images/resource/products/8.png" alt="" /></span>
							</div>
							<div class="products-block_two-icon" style="background-image:url(assets/images/icons/product-two_circle.png)"></div>
						</div>
					</div>

				</div>
			</div>
		</div>
	</section>
	<!-- End Products One -->

	<!-- Fluid One -->
	<section class="fluid-one">
		<div class="outer-container clearfix">

			<!-- Left Box -->
			<div class="left-box" style="background-image: url(assets/images/resource/fluid-1.jpg)">
				<div class="left-box_inner">
					<div class="fluid-one_image">
						<img src="assets/images/resource/fluid-1.jpg" alt="" />
					</div>
				</div>
				<div class="fluid-one_mb" style="background-image: url(assets/images/icons/fluid-one_price.png)">
					Up to <br> <span>40mb</span> Per Second
				</div>
			</div>

			<!-- Right Box -->
			<div class="right-box clearfix">
				<div class="fluid-one_image-layer" style="background-image: url(assets/images/resource/fluid-2.jpg)"></div>
				<div class="right-box_inner">
					<!-- Sec Title -->
					<div class="sec-title light">
						<div class="sec-title_title">What you Get</div>
						<h2 class="sec-title_heading">Broadband Networks at Cheap Price</h2>
					</div>
					
					<!-- Feature Block One -->
					<div class="feature-block_one">
						<div class="feature-block_one-inner">
							<div class="feature-block_one-image">
								<span class="border-one"></span>
								<span class="border-two"></span>
								<img src="assets/images/resource/feature-1.jpg" alt="" />
							</div>
							<h4 class="feature-block_one-heading">Connect Multiple Users</h4>
							Ongoing advancements, such as the deployments of 5G network& the expansion of fiber-optic..
						</div>
					</div>

					<!-- Feature Block One -->
					<div class="feature-block_one">
						<div class="feature-block_one-inner">
							<div class="feature-block_one-image">
								<span class="border-one"></span>
								<span class="border-two"></span>
								<img src="assets/images/resource/feature-2.jpg" alt="" />
							</div>
							<h4 class="feature-block_one-heading">100 Mbps Youtube</h4>
							Ongoing advancements, such as the deployments of 5G network& the expansion of fiber-optic..
						</div>
					</div>

					<div class="fluid-two_options">
						<div class="d-flex align-items-center flex-wrap">
							<div class="fluid-one_button">
								<a href="about.html" class="theme-btn btn-style-one">
									<span class="btn-wrap">
										<span class="text-one">Get Started <i class="fa-solid fa-plus fa-fw"></i></span>
										<span class="text-two">Get Started <i class="fa-solid fa-plus fa-fw"></i></span>
									</span>
								</a>
							</div>
							<div class="fluid-one_price">$<span>$90</span>/month <i>Ultra fast internet</i></div>
						</div>
					</div>

				</div>
			</div>
			
		</div>
	</section>
	<!-- End Fluid Two -->

	<!-- Internet One -->
	<section class="internet-one">
		<div class="auto-container">
			<!-- Sec Title -->
			<div class="sec-title centered">
				<div class="sec-title_title title-anim">Internet for Home</div>
				<h2 class="sec-title_heading">Choose your Internet <br> Pack by Speed</h2>
			</div>

			<div class="inner-container">
				<div class="row clearfix">
					<!-- Counter Column -->
					<div class="internet-one_counter-column col-lg-3 col-md-12 col-sm-12">
						<div class="internet-counter_outer">

							<!-- Counter Block One -->
							<div class="internet-counter_block">
								<div class="internet-counter_block-inner">
									<div class="internet-counter_block-content">
										<div class="internet-counter_block-icon">
											<i class="flaticon-tower"></i>
										</div>
										<div class="internet-counter_block-count"><span class="odometer" data-count="500"></span></div>
										<div class="internet-counter_block-text">Mbbs</div>
									</div>
								</div>
							</div>

							<!-- Counter Block One -->
							<div class="internet-counter_block active">
								<div class="internet-counter_block-inner">
									<div class="internet-counter_block-content">
										<div class="internet-counter_block-icon">
											<i class="flaticon-tower"></i>
										</div>
										<div class="internet-counter_block-count"><span class="odometer" data-count="600"></span></div>
										<div class="internet-counter_block-text">Mbbs</div>
									</div>
								</div>
							</div>

							<!-- Counter Block One -->
							<div class="internet-counter_block">
								<div class="internet-counter_block-inner">
									<div class="internet-counter_block-content">
										<div class="internet-counter_block-icon">
											<i class="flaticon-tower"></i>
										</div>
										<div class="internet-counter_block-count"><span class="odometer" data-count="700"></span></div>
										<div class="internet-counter_block-text">Mbbs</div>
									</div>
								</div>
							</div>

							<!-- Counter Block One -->
							<div class="internet-counter_block">
								<div class="internet-counter_block-inner">
									<div class="internet-counter_block-content">
										<div class="internet-counter_block-icon">
											<i class="flaticon-tower"></i>
										</div>
										<div class="internet-counter_block-count"><span class="odometer" data-count="800"></span></div>
										<div class="internet-counter_block-text">Mbbs</div>
									</div>
								</div>
							</div>

						</div>
					</div>
					<!-- Counter Column -->
					<div class="internet-one-content-column col-lg-9 col-md-12 col-sm-12">

						<!-- Internet One Content -->
						<div class="internet-one_content">
							<div class="row clearfix">

								<!-- Content -->
								<div class="content col-lg-7 col-md-8 col-sm-12">
									<div class="upper-box">
										<div class="title">Basic Package</div>
									</div>
									<div class="middle-box">
										<div class="d-flex align-items-center justify-content-between flex-wrap">
											<div class="internet-one_clock d-flex align-items-center">
												<i><img src="assets/images/icons/clock.png" alt="" /></i>
												Add an xFi gateway <br> at checkout
											</div>
											<div class="internet-one_price">
												$20 <span>/month</span>
											</div>
										</div>
									</div>

									<div class="lower-box">
										<div class="row clearfix">
											<div class="column col-lg-6 col-md-6 col-sm-6">
												<h6>600 Mbps is good for</h6>
												<ul class="internet-one_list">
													<li><i class="fa-solid fa-angles-right fa-fw"></i>HD Streaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Multiplayer gaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Wi-fi Router & prevention</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Connect Multiple Users</li>
												</ul>
											</div>
											<div class="column col-lg-6 col-md-6 col-sm-6">
												<h6>800 Mbps is good for</h6>
												<ul class="internet-one_list">
													<li><i class="fa-solid fa-angles-right fa-fw"></i>HD Streaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Multiplayer gaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Wi-fi Router & prevention</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Connect Multiple Users</li>
												</ul>
											</div>
										</div>
									</div>

								</div>
								<!-- Content -->
								<div class="image col-lg-5 col-md-4 col-sm-12">
									<div class="internet-one_image">
										<img src="assets/images/resource/internet.jpg" alt="" />
									</div>
								</div>

							</div>
						</div>

						<!-- Internet One Content -->
						<div class="internet-one_content active">
							<div class="row clearfix">

								<!-- Content -->
								<div class="content col-lg-7 col-md-8 col-sm-12">
									<div class="upper-box">
										<div class="title">Standard Package</div>
									</div>
									<div class="middle-box">
										<div class="d-flex align-items-center justify-content-between flex-wrap">
											<div class="internet-one_clock d-flex align-items-center">
												<i><img src="assets/images/icons/clock.png" alt="" /></i>
												Add an xFi gateway <br> at checkout
											</div>
											<div class="internet-one_price">
												$20 <span>/month</span>
											</div>
										</div>
									</div>

									<div class="lower-box">
										<div class="row clearfix">
											<div class="column col-lg-6 col-md-6 col-sm-6">
												<h6>600 Mbps is good for</h6>
												<ul class="internet-one_list">
													<li><i class="fa-solid fa-angles-right fa-fw"></i>HD Streaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Multiplayer gaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Wi-fi Router & prevention</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Connect Multiple Users</li>
												</ul>
											</div>
											<div class="column col-lg-6 col-md-6 col-sm-6">
												<h6>800 Mbps is good for</h6>
												<ul class="internet-one_list">
													<li><i class="fa-solid fa-angles-right fa-fw"></i>HD Streaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Multiplayer gaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Wi-fi Router & prevention</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Connect Multiple Users</li>
												</ul>
											</div>
										</div>
									</div>

								</div>
								<!-- Content -->
								<div class="image col-lg-5 col-md-4 col-sm-12">
									<div class="internet-one_image">
										<img src="assets/images/resource/internet.jpg" alt="" />
									</div>
								</div>

							</div>
						</div>

						<!-- Internet One Content -->
						<div class="internet-one_content">
							<div class="row clearfix">

								<!-- Content -->
								<div class="content col-lg-7 col-md-8 col-sm-12">
									<div class="upper-box">
										<div class="title">Premium Package</div>
									</div>
									<div class="middle-box">
										<div class="d-flex align-items-center justify-content-between flex-wrap">
											<div class="internet-one_clock d-flex align-items-center">
												<i><img src="assets/images/icons/clock.png" alt="" /></i>
												Add an xFi gateway <br> at checkout
											</div>
											<div class="internet-one_price">
												$20 <span>/month</span>
											</div>
										</div>
									</div>

									<div class="lower-box">
										<div class="row clearfix">
											<div class="column col-lg-6 col-md-6 col-sm-6">
												<h6>600 Mbps is good for</h6>
												<ul class="internet-one_list">
													<li><i class="fa-solid fa-angles-right fa-fw"></i>HD Streaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Multiplayer gaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Wi-fi Router & prevention</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Connect Multiple Users</li>
												</ul>
											</div>
											<div class="column col-lg-6 col-md-6 col-sm-6">
												<h6>800 Mbps is good for</h6>
												<ul class="internet-one_list">
													<li><i class="fa-solid fa-angles-right fa-fw"></i>HD Streaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Multiplayer gaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Wi-fi Router & prevention</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Connect Multiple Users</li>
												</ul>
											</div>
										</div>
									</div>

								</div>
								<!-- Content -->
								<div class="image col-lg-5 col-md-4 col-sm-12">
									<div class="internet-one_image">
										<img src="assets/images/resource/internet.jpg" alt="" />
									</div>
								</div>

							</div>
						</div>

						<!-- Internet One Content -->
						<div class="internet-one_content">
							<div class="row clearfix">

								<!-- Content -->
								<div class="content col-lg-7 col-md-8 col-sm-12">
									<div class="upper-box">
										<div class="title">Rocket Package</div>
									</div>
									<div class="middle-box">
										<div class="d-flex align-items-center justify-content-between flex-wrap">
											<div class="internet-one_clock d-flex align-items-center">
												<i><img src="assets/images/icons/clock.png" alt="" /></i>
												Add an xFi gateway <br> at checkout
											</div>
											<div class="internet-one_price">
												$20 <span>/month</span>
											</div>
										</div>
									</div>

									<div class="lower-box">
										<div class="row clearfix">
											<div class="column col-lg-6 col-md-6 col-sm-6">
												<h6>600 Mbps is good for</h6>
												<ul class="internet-one_list">
													<li><i class="fa-solid fa-angles-right fa-fw"></i>HD Streaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Multiplayer gaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Wi-fi Router & prevention</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Connect Multiple Users</li>
												</ul>
											</div>
											<div class="column col-lg-6 col-md-6 col-sm-6">
												<h6>800 Mbps is good for</h6>
												<ul class="internet-one_list">
													<li><i class="fa-solid fa-angles-right fa-fw"></i>HD Streaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Multiplayer gaming</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Wi-fi Router & prevention</li>
													<li><i class="fa-solid fa-angles-right fa-fw"></i>Connect Multiple Users</li>
												</ul>
											</div>
										</div>
									</div>

								</div>
								<!-- Content -->
								<div class="image col-lg-5 col-md-4 col-sm-12">
									<div class="internet-one_image">
										<img src="assets/images/resource/internet.jpg" alt="" />
									</div>
								</div>

							</div>
						</div>

					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- End Internet One -->

	<!-- Clients Two -->
	<section class="clients-two">
		<div class="clients-two_image" style="background-image:url(assets/images/background/client-bg.jpg)"></div>
		<div class="auto-container">
			<div class="inner-container">
				<div class="clients-one_slider swiper-container">
					<div class="swiper-wrapper">
						
						<!-- Slide -->
						<div class="swiper-slide">
							<div class="client-two_image">
								<a href="#"><img src="assets/images/clients/1.png" alt="" /></a>
							</div>
						</div>

						<!-- Slide -->
						<div class="swiper-slide">
							<div class="client-two_image">
								<a href="#"><img src="assets/images/clients/2.png" alt="" /></a>
							</div>
						</div>

						<!-- Slide -->
						<div class="swiper-slide">
							<div class="client-two_image">
								<a href="#"><img src="assets/images/clients/3.png" alt="" /></a>
							</div>
						</div>

						<!-- Slide -->
						<div class="swiper-slide">
							<div class="client-two_image">
								<a href="#"><img src="assets/images/clients/4.png" alt="" /></a>
							</div>
						</div>

						<!-- Slide -->
						<div class="swiper-slide">
							<div class="client-two_image">
								<a href="#"><img src="assets/images/clients/5.png" alt="" /></a>
							</div>
						</div>

						<!-- Slide -->
						<div class="swiper-slide">
							<div class="client-two_image">
								<a href="#"><img src="assets/images/clients/1.png" alt="" /></a>
							</div>
						</div>

					</div>

				</div>
			</div>
		</div>
	</section>
	<!-- Clients Two -->

	<!-- Team Three -->
	<section class="team-three">
		<div class="auto-container_two">
			<div class="inner-container">
				<!-- Sec Title -->
				<div class="sec-title centered">
					<div class="sec-title_title title-anim">Support Team</div>
					<h2 class="sec-title_heading">Professional Team <br> Mamber</h2>
				</div>
				<div class="row clearfix">

					<!-- Team Block Three -->
					<div class="team-block_three col-lg-4 col-md-6 col-sm-6">
						<div class="team-block_three-inner wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
							<div class="team-block_three-image">
								<img src="assets/images/resource/team-8.jpg" alt="" />
								<!-- Slider One Socials -->
								<ul class="team-block_three-socials">
									<li><a class="twitter" href="#"><i class="fa-brands fa-twitter fa-fw"></i></a></li>
									<li><a class="instagram" href="#"><i class="fa-brands fa-instagram fa-fw"></i></a></li>
									<li><a class="facebook" href="#"><i class="fa-brands fa-facebook-f fa-fw"></i></a></li>
								</ul>
								<div class="team-block_three-content">
									<h4 class="team-block_three-heading"><a href="team-detail.html">Ralph Simmons</a></h4>
									<div class="team-block_three-designation">Marketing Expert</div>
								</div>
							</div>
						</div>
					</div>

					<!-- Team Block Three -->
					<div class="team-block_three col-lg-4 col-md-6 col-sm-6">
						<div class="team-block_three-inner wow fadeInLeft" data-wow-delay="150ms" data-wow-duration="1500ms">
							<div class="team-block_three-image">
								<img src="assets/images/resource/team-9.jpg" alt="" />
								<!-- Slider One Socials -->
								<ul class="team-block_three-socials">
									<li><a class="twitter" href="#"><i class="fa-brands fa-twitter fa-fw"></i></a></li>
									<li><a class="instagram" href="#"><i class="fa-brands fa-instagram fa-fw"></i></a></li>
									<li><a class="facebook" href="#"><i class="fa-brands fa-facebook-f fa-fw"></i></a></li>
								</ul>
								<div class="team-block_three-content">
									<h4 class="team-block_three-heading"><a href="team-detail.html">Mitra D. Singh</a></h4>
									<div class="team-block_three-designation">Creative Director</div>
								</div>
							</div>
						</div>
					</div>

					<!-- Team Block Three -->
					<div class="team-block_three col-lg-4 col-md-6 col-sm-6">
						<div class="team-block_three-inner wow fadeInLeft" data-wow-delay="300ms" data-wow-duration="1500ms">
							<div class="team-block_three-image">
								<img src="assets/images/resource/team-10.jpg" alt="" />
								<!-- Slider One Socials -->
								<ul class="team-block_three-socials">
									<li><a class="twitter" href="#"><i class="fa-brands fa-twitter fa-fw"></i></a></li>
									<li><a class="instagram" href="#"><i class="fa-brands fa-instagram fa-fw"></i></a></li>
									<li><a class="facebook" href="#"><i class="fa-brands fa-facebook-f fa-fw"></i></a></li>
								</ul>
								<div class="team-block_three-content">
									<h4 class="team-block_three-heading"><a href="team-detail.html">Danny Warnor</a></h4>
									<div class="team-block_three-designation">Creative Director</div>
								</div>
							</div>
						</div>
					</div>

				</div>
			</div>
		</div>
	</section>
	<!-- End Team Three -->

	<!-- Movie One -->
	<section class="movie-one">
		<div class="movie-one_image" style="background-image:url(assets/images/background/3.jpg)"></div>
		<div class="auto-container">
			<!-- Sec Title -->
			<div class="sec-title centered light">
				<div class="sec-title_title title-anim">Movies Categories</div>
				<h2 class="sec-title_heading">Watch anything via <br> the Category</h2>
			</div>
			<div class="row clearfix">
				<div class="column col-lg-6 col-md-12 col-sm-12">
					<div class="row clearfix">

						<!-- Moview Block One -->
						<div class="movie-block_one col-lg-4 col-md-4 col-sm-6">
							<div class="movie-block_one-inner">
								<div class="movie-block_one-icon">
									<i class="flaticon-server"></i>
								</div>
								<h4 class="movie-block_one-heading"><a href="movie-detail.html">Adventure</a></h4>
							</div>
						</div>

						<!-- Moview Block One -->
						<div class="movie-block_one col-lg-4 col-md-4 col-sm-6">
							<div class="movie-block_one-inner">
								<div class="movie-block_one-icon">
									<i class="flaticon-server"></i>
								</div>
								<h4 class="movie-block_one-heading"><a href="movie-detail.html">Historical</a></h4>
							</div>
						</div>

						<!-- Moview Block One -->
						<div class="movie-block_one col-lg-4 col-md-4 col-sm-6">
							<div class="movie-block_one-inner">
								<div class="movie-block_one-icon">
									<i class="flaticon-server"></i>
								</div>
								<h4 class="movie-block_one-heading"><a href="movie-detail.html">Western</a></h4>
							</div>
						</div>

						<!-- Moview Block One -->
						<div class="movie-block_one col-lg-4 col-md-4 col-sm-6">
							<div class="movie-block_one-inner">
								<div class="movie-block_one-icon">
									<i class="flaticon-server"></i>
								</div>
								<h4 class="movie-block_one-heading"><a href="movie-detail.html">Biography</a></h4>
							</div>
						</div>

						<!-- Moview Block One -->
						<div class="movie-block_one col-lg-4 col-md-4 col-sm-6">
							<div class="movie-block_one-inner">
								<div class="movie-block_one-icon">
									<i class="flaticon-server"></i>
								</div>
								<h4 class="movie-block_one-heading"><a href="movie-detail.html">Mystery</a></h4>
							</div>
						</div>

						<!-- Moview Block One -->
						<div class="movie-block_one col-lg-4 col-md-4 col-sm-6">
							<div class="movie-block_one-inner">
								<div class="movie-block_one-icon">
									<i class="flaticon-server"></i>
								</div>
								<h4 class="movie-block_one-heading"><a href="movie-detail.html">Comedy</a></h4>
							</div>
						</div>

					</div>
				</div>
				<div class="column col-lg-6 col-md-12 col-sm-12">
					<a href="https://www.youtube.com/watch?v=YS3PwmOQ1Fc" class="lightbox-video movie-one_play"><span class="fa-solid fa-circle-pause fa-fw"><i class="ripple"></i></span></a>
				</div>
			</div>
		</div>
	</section>
	<!-- End Movie One -->

	<!-- Gallery Three -->
	<section class="gallery-three">
		<div class="auto-container">
			<!-- Sec Title -->
			<div class="sec-title centered">
				<div class="sec-title_title title-anim">Now Streaming</div>
				<h2 class="sec-title_heading">Popular TV Shows now <br> Streaming</h2>
			</div>
			<div class="masonry-items-container row clearfix">

				<!-- Gallery Block Three -->
				<div class="gallery-block_three masonry-item col-lg-4 col-md-6 sol-sm-12">
					<div class="gallery-block_three-inner">
						<div class="gallery-block_three-image">
							<img src="assets/images/gallery/11.jpg" alt="" />
							<div class="gallery-block_three-overlay">
								<div class="gallery-block_three-price">Fri-Sat <br> 10.00 PM</div>
								<div class="gallery-block_three-content">
									<div class="gallery-block_three-rating">
										<span class="fa fa-star"></span>
										(90 Reviews)
									</div>
									<h6 class="gallery-block_three-heading"><a href="project-detail.html">Fifa World Cup 2022</a></h6>
									<a class="gallery-block_three-arrow" href="project-detail.html">
										<i class="fa-solid fa-arrow-right-long fa-fw"></i>
									</a>
									<div class="gallery-block_three-pattern" style="background-image:url(assets/images/background/pattern-3.png)"></div>
								</div>
							</div>
						</div>
					</div>
				</div>

				<!-- Gallery Block Three -->
				<div class="gallery-block_three masonry-item col-lg-4 col-md-6 sol-sm-12">
					<div class="gallery-block_three-inner">
						<div class="gallery-block_three-image">
							<img src="assets/images/gallery/12.jpg" alt="" />
							<div class="gallery-block_three-overlay">
								<div class="gallery-block_three-price">Fri-Sat <br> 10.00 PM</div>
								<div class="gallery-block_three-content">
									<div class="gallery-block_three-rating">
										<span class="fa fa-star"></span>
										(90 Reviews)
									</div>
									<h6 class="gallery-block_three-heading"><a href="project-detail.html">Fifa World Cup 2022</a></h6>
									<a class="gallery-block_three-arrow" href="project-detail.html">
										<i class="fa-solid fa-arrow-right-long fa-fw"></i>
									</a>
									<div class="gallery-block_three-pattern" style="background-image:url(assets/images/background/pattern-3.png)"></div>
								</div>
							</div>
						</div>
					</div>
				</div>

				<!-- Gallery Block Three -->
				<div class="gallery-block_three masonry-item col-lg-4 col-md-12 sol-sm-12">
					<div class="gallery-block_three-inner">
						<div class="gallery-block_three-image">
							<img src="assets/images/gallery/13.jpg" alt="" />
							<div class="gallery-block_three-overlay">
								<div class="gallery-block_three-price">Fri-Sat <br> 10.00 PM</div>
								<div class="gallery-block_three-content">
									<div class="gallery-block_three-rating">
										<span class="fa fa-star"></span>
										(90 Reviews)
									</div>
									<h6 class="gallery-block_three-heading"><a href="project-detail.html">Fifa World Cup 2022</a></h6>
									<a class="gallery-block_three-arrow" href="project-detail.html">
										<i class="fa-solid fa-arrow-right-long fa-fw"></i>
									</a>
									<div class="gallery-block_three-pattern" style="background-image:url(assets/images/background/pattern-3.png)"></div>
								</div>
							</div>
						</div>
					</div>
				</div>

				<!-- Gallery Block Three -->
				<div class="gallery-block_three masonry-item col-lg-8 col-md-12 sol-sm-12">
					<div class="gallery-block_three-inner">
						<div class="gallery-block_three-image">
							<img src="assets/images/gallery/14.jpg" alt="" />
							<div class="gallery-block_three-overlay">
								<div class="gallery-block_three-price">Fri-Sat <br> 10.00 PM</div>
								<div class="gallery-block_three-content">
									<div class="gallery-block_three-rating">
										<span class="fa fa-star"></span>
										(90 Reviews)
									</div>
									<h6 class="gallery-block_three-heading"><a href="project-detail.html">Fifa World Cup 2022</a></h6>
									<a class="gallery-block_three-arrow" href="project-detail.html">
										<i class="fa-solid fa-arrow-right-long fa-fw"></i>
									</a>
									<div class="gallery-block_three-pattern" style="background-image:url(assets/images/background/pattern-3.png)"></div>
								</div>
							</div>
						</div>
					</div>
				</div>

				<!-- Gallery Block Three -->
				<div class="gallery-block_three masonry-item col-lg-4 col-md-6 sol-sm-12">
					<div class="gallery-block_three-inner">
						<div class="gallery-block_three-image">
							<img src="assets/images/gallery/15.jpg" alt="" />
							<div class="gallery-block_three-overlay">
								<div class="gallery-block_three-price">Fri-Sat <br> 10.00 PM</div>
								<div class="gallery-block_three-content">
									<div class="gallery-block_three-rating">
										<span class="fa fa-star"></span>
										(90 Reviews)
									</div>
									<h6 class="gallery-block_three-heading"><a href="project-detail.html">Fifa World Cup 2022</a></h6>
									<a class="gallery-block_three-arrow" href="project-detail.html">
										<i class="fa-solid fa-arrow-right-long fa-fw"></i>
									</a>
									<div class="gallery-block_three-pattern" style="background-image:url(assets/images/background/pattern-3.png)"></div>
								</div>
							</div>
						</div>
					</div>
				</div>

			</div>
		</div>
	</section>
	<!-- End Gallery Three -->

	<!-- Testimonial Three -->
	<section class="testimonial-three">
		<div class="auto-container_two">
			<!-- Sec Title -->
			<div class="sec-title centered">
				<div class="sec-title_title title-anim">Our Feedbacks</div>
				<h2 class="sec-title_heading">What they’re Talking <br> about ?</h2>
			</div>
			<div class="inner-container">
				<div class="testimonial-one_carousel swiper-container">
					<div class="swiper-wrapper">
						
						<!-- Slide -->
						<div class="swiper-slide">
							<!-- Testimonial Block Three -->
							<div class="testimonial-block_three">
								<div class="testimonial-block_three-inner">
									<div class="testimonial-block_three-color">
										<div class="testimonial-block_three-pattern" style="background-image:url(assets/images/background/pattern-4.png)"></div>
									</div>
									<div class="d-flex justify-content-between align-items-center flex-wrap">
										<div class="testimonial-block_three-quote">
											<i class="fa-solid fa-quote-left fa-fw"></i>
										</div>
										<div class="testimonial-block_three-rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<i>(5.0)</i>
										</div>
									</div>
									<div class="testimonial-block_three-text">Broadband providers often differentiate their services based on factors like speed, reliability & customer support. Quality of Service agreement...</div>
									<div class="testimonial-block_three-author_box d-flex align-items-center flex-wrap">
										<div class="testimonial-block_three-author">
											<img src="assets/images/resource/author-6.jpg" alt="" />
										</div>
										<span>Jessica Brown <i>Co-Founder</i></span>
									</div>
								</div>
							</div>
						</div>

						<!-- Slide -->
						<div class="swiper-slide">
							<!-- Testimonial Block Three -->
							<div class="testimonial-block_three">
								<div class="testimonial-block_three-inner">
									<div class="testimonial-block_three-color">
										<div class="testimonial-block_three-pattern" style="background-image:url(assets/images/background/pattern-4.png)"></div>
									</div>
									<div class="d-flex justify-content-between align-items-center flex-wrap">
										<div class="testimonial-block_three-quote">
											<i class="fa-solid fa-quote-left fa-fw"></i>
										</div>
										<div class="testimonial-block_three-rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<i>(5.0)</i>
										</div>
									</div>
									<div class="testimonial-block_three-text">Broadband providers often differentiate their services based on factors like speed, reliability & customer support. Quality of Service agreement...</div>
									<div class="testimonial-block_three-author_box d-flex align-items-center flex-wrap">
										<div class="testimonial-block_three-author">
											<img src="assets/images/resource/author-7.jpg" alt="" />
										</div>
										<span>Jessica Brown <i>Co-Founder</i></span>
									</div>
								</div>
							</div>
						</div>

						<!-- Slide -->
						<div class="swiper-slide">
							<!-- Testimonial Block Three -->
							<div class="testimonial-block_three">
								<div class="testimonial-block_three-inner">
									<div class="testimonial-block_three-color">
										<div class="testimonial-block_three-pattern" style="background-image:url(assets/images/background/pattern-4.png)"></div>
									</div>
									<div class="d-flex justify-content-between align-items-center flex-wrap">
										<div class="testimonial-block_three-quote">
											<i class="fa-solid fa-quote-left fa-fw"></i>
										</div>
										<div class="testimonial-block_three-rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<i>(5.0)</i>
										</div>
									</div>
									<div class="testimonial-block_three-text">Broadband providers often differentiate their services based on factors like speed, reliability & customer support. Quality of Service agreement...</div>
									<div class="testimonial-block_three-author_box d-flex align-items-center flex-wrap">
										<div class="testimonial-block_three-author">
											<img src="assets/images/resource/author-8.jpg" alt="" />
										</div>
										<span>Jessica Brown <i>Co-Founder</i></span>
									</div>
								</div>
							</div>
						</div>

						<!-- Slide -->
						<div class="swiper-slide">
							<!-- Testimonial Block Three -->
							<div class="testimonial-block_three">
								<div class="testimonial-block_three-inner">
									<div class="testimonial-block_three-color">
										<div class="testimonial-block_three-pattern" style="background-image:url(assets/images/background/pattern-4.png)"></div>
									</div>
									<div class="d-flex justify-content-between align-items-center flex-wrap">
										<div class="testimonial-block_three-quote">
											<i class="fa-solid fa-quote-left fa-fw"></i>
										</div>
										<div class="testimonial-block_three-rating">
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<span class="fa fa-star"></span>
											<i>(5.0)</i>
										</div>
									</div>
									<div class="testimonial-block_three-text">Broadband providers often differentiate their services based on factors like speed, reliability & customer support. Quality of Service agreement...</div>
									<div class="testimonial-block_three-author_box d-flex align-items-center flex-wrap">
										<div class="testimonial-block_three-author">
											<img src="assets/images/resource/author-9.jpg" alt="" />
										</div>
										<span>Jessica Brown <i>Co-Founder</i></span>
									</div>
								</div>
							</div>
						</div>

					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- End Testimonial Three -->

	<!-- News Three -->
	<section class="news-three">
		<div class="auto-container_two">
			<div class="inner-container">
				<!-- Sec Title -->
				<div class="sec-title d-flex justify-content-between align-items-center flex-wrap">
					<div class="left-box">
						<div class="sec-title_title title-anim">our news</div>
						<h2 class="sec-title_heading">Articles from the <br> Blog</h2>
					</div>
					<div class="news-three_button">
						<a href="blog.html" class="theme-btn btn-style-one">
							<span class="btn-wrap">
								<span class="text-one">View More Blog <i class="fa-solid fa-plus fa-fw"></i></span>
								<span class="text-two">View More Blog <i class="fa-solid fa-plus fa-fw"></i></span>
							</span>
						</a>
					</div>
				</div>
				<div class="row clearfix">

					<!-- News Block Three -->
					<div class="news-block_three col-lg-3 col-md-6 col-sm-6">
						<div class="news-block_three-inner wow fadeInLeft" data-wow-delay="0ms" data-wow-duration="1500ms">
							<div class="news-block_three-image">
								<a href="blog-detail.html"><img src="assets/images/resource/news-7.jpg" alt="" /></a>
							</div>
							<div class="news-block_three-content">
								<h4 class="news-block_three-heading"><a href="blog-detail.html">How can change the IP from your wi-fi</a></h4>
								<ul class="news-block_three-meta">
									<li><i class="fa-regular fa-user fa-fw"></i>admin</li>
									<li><i class="fa-regular fa-comments fa-fw"></i>01</li>
									<li class="news-block_three-date">24 oct</li>
								</ul>
								<a href="blog-detail.html" class="news-block_three-more">
									More Details <span class="fa-solid fa-plus fa-fw"></span>
								</a>
							</div>
						</div>
					</div>

					<!-- News Block Three -->
					<div class="news-block_three col-lg-3 col-md-6 col-sm-6">
						<div class="news-block_three-inner wow fadeInLeft" data-wow-delay="150ms" data-wow-duration="1500ms">
							<div class="news-block_three-image">
								<a href="blog-detail.html"><img src="assets/images/resource/news-8.jpg" alt="" /></a>
							</div>
							<div class="news-block_three-content">
								<h4 class="news-block_three-heading"><a href="blog-detail.html">Why my satellite is better than yours</a></h4>
								<ul class="news-block_three-meta">
									<li><i class="fa-regular fa-user fa-fw"></i>admin</li>
									<li><i class="fa-regular fa-comments fa-fw"></i>01</li>
									<li class="news-block_three-date">24 oct</li>
								</ul>
								<a href="blog-detail.html" class="news-block_three-more">
									More Details <span class="fa-solid fa-plus fa-fw"></span>
								</a>
							</div>
						</div>
					</div>

					<!-- News Block Four -->
					<div class="news-block_four col-lg-6 col-md-6 col-sm-12">
						<div class="news-block_four-inner wow fadeInLeft" data-wow-delay="150ms" data-wow-duration="1500ms">
							<div class="news-block_four-image">
								<img src="assets/images/resource/news-9.jpg" alt="" />
								<div class="news-block_four-content">
									<h4 class="news-block_four-heading"><a href="blog-detail.html">Becomes the Best Sale <br> Marketer</a></h4>
									<ul class="news-block_four-meta">
										<li><i class="fa-regular fa-user fa-fw"></i>admin</li>
										<li><i class="fa-regular fa-comments fa-fw"></i>01</li>
										<li class="news-block_four-date">24 oct</li>
									</ul>
									<a href="blog-detail.html" class="news-block_four-more">
										More Details <span class="fa-solid fa-plus fa-fw"></span>
									</a>
								</div>
							</div>
						</div>
					</div>

				</div>
			</div>
		</div>
	</section>
	<!-- End News Three -->

	<!-- Footer Style Two -->
	<footer class="footer-style_two">
		<div class="footer-style_two-image" style="background-image:url(assets/images/background/2.jpg)"></div>
		<div class="auto-container_two">
			<!-- Upper Box -->
			<div class="upper-box">
				<div class="row clearfix">
					
					<!-- Logo Column -->
					<div class="footer-two_logo-column col-lg-6 col-md-12 col-sm-12">
						<div class="logo"><a href="index.html"><img src="assets/images/logo-3.png" alt="" title=""></a></div>
						<!-- Social Box -->
						<div class="footer-two_socials">
							<a href="https://facebook.com/"><i class="fa-brands fa-facebook-f"></i></a>
							<a href="https://twitter.com/"><i class="fa-brands fa-twitter"></i></a>
							<a href="https://youtube.com/"><i class="fa-brands fa-youtube"></i></a>
							<a href="https://instagram.com/"><i class="fa-brands fa-instagram"></i></a>
						</div>
					</div>

					<!-- Subscribe Column -->
					<div class="footer-two_subscribe-column col-lg-6 col-md-12 col-sm-12">
						<div class="inner-column">
							<h4>Sign up to get latest <br> Updates</h4>
							<div class="text">Latest news, AI models & fun memes from the community.</div>
							<div class="subscribe-box">
								<form method="post" action="https://html.yogsthemes.com/demo/banqix/contact.html">
									<div class="form-group">
										<input type="email" name="search-field" value="" placeholder="Enter Your Email" required>
										<button type="submit" class="theme-btn btn-style-one">
											<span class="btn-wrap">
												<span class="text-one">Subscribe Now <i class="fa-solid fa-plus fa-fw"></i></span>
												<span class="text-two">Subscribe Now <i class="fa-solid fa-plus fa-fw"></i></span>
											</span>
										</button>
									</div>
								</form>
							</div>
						</div>
					</div>

				</div>
			</div>
			<!-- Widgets Section -->
			<div class="widgets-section">
				<div class="row clearfix">

					<!-- Footer Column -->
					<div class="footer_column col-lg-4 col-md-6 col-sm-12">
						<div class="footer-widget gallery-widget">
							<h4 class="footer-title">Service Schedule</h4>
							<ul class="timing-list">
								<li>Mon-Tues<span>03.00AM - 08.00PM</span></li>
								<li>Wedne-Thur<span>07.00AM - 09.00PM</span></li>
								<li>Fri-Sat<span>06.00AM - 11.00PM</span></li>
							</ul>
						</div>
					</div>

					<!-- Footer Column -->
					<div class="footer_column col-lg-4 col-md-6 col-sm-12">
						<div class="footer-widget lists-widget">
							<h4 class="footer-title">Get Free Link</h4>
							<ul class="footer-list_two">
								<li><a href="#">IT Consulting</a></li>
								<li><a href="#">Others</a></li>
								<li><a href="#">Data Analytics</a></li>
								<li><a href="#">UI & UX Design</a></li>
								<li><a href="#">Network Solutions</a></li>
								<li><a href="#">Software Development</a></li>
							</ul>
						</div>
					</div>

					<!-- Footer Column -->
					<div class="footer_column col-lg-4 col-md-6 col-sm-12">
						<div class="footer-widget instagram-widget">
							<h4 class="footer-title">Instagram</h4>
							<div class="images-outer clearfix">
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/1.jpg"><img src="assets/images/gallery/instagram-1.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/2.jpg"><img src="assets/images/gallery/instagram-2.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/3.jpg"><img src="assets/images/gallery/instagram-3.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/1.jpg"><img src="assets/images/gallery/instagram-1.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/2.jpg"><img src="assets/images/gallery/instagram-2.jpg" alt=""></a></figure>
								<!--Image Box-->
								<figure class="image-box"><a class="lightbox-image" href="assets/images/gallery/3.jpg"><img src="assets/images/gallery/instagram-3.jpg" alt=""></a></figure>
							</div>
						</div>
					</div>

				</div>
			</div>

			<div class="footer-bottom">
				<div class="d-flex justify-content-between align-items-center flex-wrap">

					<ul class="footer-bottom_nav">
						<li><a href="#">Policy & Privacy</a></li>
						<li><a href="#">Terms & Condition</a></li>
					</ul>

					<!-- Copyright -->
					<div class="main-footer_copyright">Copyright &copy; 2023. All Rights Reserved.</div>

				</div>
			</div>

		</div>
	</footer>
	<!-- End Footer Style Two -->

	<!-- Search Popup -->
	<div class="search-popup">
		<div class="color-layer"></div>
		<button class="close-search"><span class="flaticon-close-1"></span></button>
		<form method="post" action="https://html.yogsthemes.com/demo/banqix/blog.html">
			<div class="form-group">
				<input type="search" name="search-field" value="" placeholder="Search Here" required="">
				<button class="fa fa-solid fa-magnifying-glass fa-fw" type="submit"></button>
			</div>
		</form>
	</div>
	<!-- End Search Popup -->
	
	<!-- Color Palate / Color Switcher -->
	<div class="color-palate">
		<div class="color-trigger">
			<i class="fa fa-solid fa-gear fa-fw"></i>
		</div>
		<div class="color-palate-inner">
			<div class="color-palate-head">
				<h6>Choose Options</h6>
			</div>
			
			<!-- Colors -->
			<div class="various-color clearfix">
				<div class="colors-list">
					<span class="palate default-color active" data-theme-file="assets/css/color-themes/default-color.css"></span>
					<span class="palate blue-color" data-theme-file="assets/css/color-themes/blue-color.css"></span>
					<span class="palate olive-color" data-theme-file="assets/css/color-themes/olive-color.css"></span>
					<span class="palate orange-color" data-theme-file="assets/css/color-themes/orange-color.css"></span>
					<span class="palate purple-color" data-theme-file="assets/css/color-themes/purple-color.css"></span>
					<span class="palate green-color" data-theme-file="assets/css/color-themes/green-color.css"></span>
					<span class="palate brown-color" data-theme-file="assets/css/color-themes/brown-color.css"></span>
					<span class="palate yellow-color" data-theme-file="assets/css/color-themes/yellow-color.css"></span>
				</div>
			</div>
					
			<h6>RTL Version</h6>
			<ul class="rtl-version option-box"> <li class="rtl">RTL Version</li> <li>LTR Version</li> </ul>
			<h6>Want Sticky Header</h6>
			<ul class="header-version option-box"> <li class="box">No</li> <li>Yes</li></ul>
			<h6>Dark Verion</h6>
			<ul class="dark-version option-box"> <li class="box">Yes</li> <li>No</li></ul>
			
			<div class="purchase-box">
				You will find much more options for colors and styling in admin panel. This color picker is used only for demonstation purposes.
				<a href="#" class="theme-btn btn-style-two">
					<span class="btn-wrap">
						<span class="text-one">buy now</span>
						<span class="text-two">buy now</span>
					</span>
				</a>
			</div>
			
		</div>
	</div>
	<!-- End Color Palate / Color Switcher -->
	
</div>
<!-- End PageWrapper -->

<div class="progress-wrap">
	<svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
		<path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
	</svg>
</div>

<script src="assets/js/jquery.js"></script>
<script src="assets/js/popper.min.js"></script>
<script src="assets/js/bootstrap.min.js"></script>
<script src="assets/js/appear.js"></script>
<script src="assets/js/parallax.min.js"></script>
<script src="assets/js/tilt.jquery.min.js"></script>
<script src="assets/js/jquery.paroller.min.js"></script>
<script src="assets/js/wow.js"></script>
<script src="assets/js/swiper.min.js"></script>
<script src="assets/js/backtotop.js"></script>
<script src="assets/js/odometer.js"></script>
<script src="assets/js/parallax-scroll.js"></script>

<script src="assets/js/gsap.min.js"></script>
<script src="assets/js/SplitText.min.js"></script>
<script src="assets/js/ScrollTrigger.min.js"></script>
<script src="assets/js/ScrollToPlugin.min.js"></script>
<script src="assets/js/ScrollSmoother.min.js"></script>

<script src="assets/js/isotope.js"></script>
<script src="assets/js/magnific-popup.min.js"></script>
<script src="assets/js/jquery.meanmenu.min.js"></script>
<script src="assets/js/nav-tool.js"></script>
<script src="assets/js/jquery-ui.js"></script>
<script src="assets/js/element-in-view.js"></script>
<script src="assets/js/color-settings.js"></script>
<script src="assets/js/script.js"></script>

</body>

<!-- Mirrored from html.yogsthemes.com/demo/banqix/index-3.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:00:28 GMT -->
</html>