<!DOCTYPE html><html lang="en"><!-- Mirrored from html.kodesolution.com/2023/satnet-html/index-3.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:13:35 GMT --><head>
<meta charset="utf-8">
<title>Satnet | Broadband HTML Template | Home Page 03</title>
<!-- Stylesheets -->
<link href="css/animate.css" rel="stylesheet">
<link href="css/bootstrap.min.css" rel="stylesheet">
<link href="css/slick.css" rel="stylesheet">
<link href="css/slick-theme.css" rel="stylesheet">
<link href="css/select2.min.css" rel="stylesheet">
<link href="css/swipebox.min.css" rel="stylesheet">
<link href="css/swiper-bundle.min.css" rel="stylesheet">
<link href="css/style.css" rel="stylesheet">

<link rel="shortcut icon" href="images/favicon2.png" type="image/x-icon">
<link rel="icon" href="images/favicon2.png" type="image/x-icon">

<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">
<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
<link rel="stylesheet" href="css/custom_elements.css?svt8uqGw" id="custom-elements-css"><link rel="stylesheet" href="css/code_editor_styles.css?4orGFlIb" id="custom-css"><link rel="stylesheet" href="font-awesome/font-awesome.min.css?Ji0liDHJ" id="font-awesome"></head>

<body class="layout3">

<div class="page-wrapper">

    <!-- Main Header-->
	<header class="main-header header-style-three">
		<!-- Header Top -->
		<div class="header-top">
			<div class="container">
				<div class="header-top-content">
					<div class="top-left">
						<!-- Info List -->
                        <ul class="info-list">
                            <li>
                                <img src="images/icons/header-phone-white.png" alt="">
                                <span><strong>Phone.</strong>  +88(9800) 6802</span>
                            </li>
                            <li>
                                <img src="images/icons/header-mail-white.png" alt="">
                                <span><strong>Email.</strong> <a href="https://html.kodesolution.com/cdn-cgi/l/email-protection" class="__cf_email__" data-cfemail="b5c0c6d0c7dbd4d8d0f5d1dad8d4dcdb9bd6dad8">[email&nbsp;protected]</a></span>
                            </li>
                        </ul>
					</div>
					<ul class="social-links">
                        <li><span>Follow Us!</span></li>
                        <li><a href="#" title=""><i class="fab fa-facebook"></i></a></li>
                        <li><a href="#" title=""><i class="fab fa-google-plus-g"></i></a></li>
                        <li><a href="#" title=""><i class="fa fa-x"></i></a></li>
                    </ul>
				</div>
			</div>
		</div>
		<!-- Header Top -->

        <div class="header-lower">
            <!-- Main box -->
            <div class="main-box">
                <div class="logo-box">
                    <div class="logo"><a href="index.html"><img src="images/logo-v3-white.png" alt="" title="Satnet"></a></div>
                </div>

                <!--Nav Box-->
                <div class="nav-outer">    
                    <nav class="nav main-menu">
                        <ul class="navigation">
                            <li class="current dropdown"><a href="index.html">Home</a>
                                <ul>
                                    <li><a href="index.html">Home page 01</a></li>
                                    <li><a href="index-2.html">Home page 02</a></li>
                                    <li><a href="index-3.html">Home page 03</a></li>
                                    <li><a href="index-4.html">Home page 04</a></li>
                                    <li class="dropdown"><a href="#">Single Styles</a>
                                        <ul>
                                            <li><a href="index-1-single.html">Single Style One</a></li>
                                            <li><a href="index-2-single.html">Single Style Two</a></li>
                                            <li><a href="index-3-single.html">Single Style Two</a></li>
                                            <li><a href="index-4-single.html">Single Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Dark Styles</a>
                                        <ul>
                                            <li><a href="index-1-dark.html">Darl Style One</a></li>
                                            <li><a href="index-2-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-3-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-4-dark.html">Darl Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Header Styles</a>
                                        <ul>
                                            <li><a href="index.html">Header Style One</a></li>
                                            <li><a href="index-2.html">Header Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="index-1-rtl.html">RTL Style One</a></li>
                                </ul>
                            </li>
                            <li class="dropdown"><a href="page-services.html">Services</a>
                                <ul>
                                    <li><a href="page-services.html">Services Grid</a></li>
                                    <li><a href="page-service-details.html">Service Details</a></li>
                                </ul>
                            </li>
							<li class="dropdown"><a href="page-about.html">Pages</a>
								<ul>
									<li><a href="page-about.html">About</a></li>
									<li><a href="page-movie.html">Movie</a></li>
									<li><a href="page-pricing.html">Pricing</a></li>
									<li class="dropdown"><a href="shop-products.html">Shop</a>
										<ul>
											<li><a href="shop-products.html">Products</a></li>
											<li><a href="shop-products-sidebar.html">Products Sidebar</a></li>
											<li><a href="shop-product-details.html">Product Details</a></li>
											<li><a href="shop-cart.html">Cart</a></li>
											<li><a href="shop-checkout.html">Checkout</a></li>
										</ul>
									</li>
									<li><a href="page-team.html">Team</a></li>
									<li><a href="page-testimonial.html">Testimonial</a></li>
									<li><a href="page-faq.html">FAQ</a></li>
									<li><a href="page-404.html">Page 404</a></li>
								</ul>
							</li>
							<li class="dropdown"><a href="news-grid.html">News</a>
								<ul>
									<li><a href="news-grid.html">News Grid</a></li>
									<li><a href="news-details.html">News Details</a></li>
								</ul>
							</li>
                            <li><a href="page-contact.html">Contact</a></li>
                        </ul>
                    </nav>
                    <!-- Main Menu End-->
                </div>

                <div class="outer-box">
                    <!-- Header Search -->
						<button class="search-btn">
                            <i class="flaticon-search"></i>
						</button>
						<button class="login-btn">
                            <i class="flaticon-user"></i>
						</button>
                    <a href="page-movie.html" title="" class="header-btn"><i class="icon fa fa-bolt"></i>Trending</a>
                    <div class="mobile-nav-toggler"><span class="icon lnr-icon-bars"></span></div>
                    <!-- Mobile Nav toggler -->
                </div>
            </div>
        </div>
		
		<!-- Mobile Menu  -->
		<div class="mobile-menu">
			<div class="menu-backdrop"></div>
		
			<!--Here Menu Will Come Automatically Via Javascript / Same Menu as in Header-->
			<nav class="menu-box">
				<div class="upper-box">
					<div class="nav-logo"><a href="index.html"><img src="images/logo-v2-white.png" alt="" title=""></a></div>
					<div class="close-btn"><i class="icon fa fa-times"></i></div>
				</div>
		
				<ul class="navigation clearfix">
					<!--Keep This Empty / Menu will come through Javascript-->
				</ul>
				<ul class="contact-list-one">
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<i class="icon lnr-icon-phone-handset"></i>
							<span class="title">Call Now</span>
							<a href="tel:+92880098670">+92 (8800) - 98670</a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-envelope1"></span>
							<span class="title">Send Email</span>
							<a href="https://html.kodesolution.com/cdn-cgi/l/email-protection#234b464f5363404c4e53424d5a0d404c4e"><span class="__cf_email__" data-cfemail="3d5558514d7d5e52504d5c5344135e5250">[email&nbsp;protected]</span></a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-clock"></span>
							<span class="title">Send Email</span>
							Mon - Sat 8:00 - 6:30, Sunday - CLOSED
						</div>
					</li>
				</ul>
		
		
				<ul class="social-links">
					<li><a href="#"><i class="fa fa-x"></i></a></li>
					<li><a href="#"><i class="fab fa-facebook-f"></i></a></li>
					<li><a href="#"><i class="fab fa-pinterest"></i></a></li>
					<li><a href="#"><i class="fab fa-instagram"></i></a></li>
				</ul>
			</nav>
		</div><!-- End Mobile Menu -->

		<!-- Header Search -->
		<div class="search-popup">
			<span class="search-back-drop"></span>
			<button class="close-search"><span class="fa fa-times"></span></button>
		
			<div class="search-inner">
				<form method="post" action="https://html.kodesolution.com/2023/satnet-html/index.html">
					<div class="form-group">
						<input type="search" name="search-field" value="" placeholder="Search..." required="">
						<button type="submit"><i class="fa fa-search"></i></button>
					</div>
				</form>
			</div>
		</div>
		<!-- End Header Search -->

		<!-- Sticky Header  -->
		<div class="sticky-header">
			<div class="auto-container">
				<div class="inner-container">
					<!--Logo-->
					<div class="logo">
						<a href="index.html" title=""><img src="images/logo-v2-white.png" alt="" title=""></a>
					</div>
		
					<!--Right Col-->
					<div class="nav-outer">
						<!-- Main Menu -->
						<nav class="main-menu">
							<div class="navbar-collapse show collapse clearfix">
								<ul class="navigation clearfix">
									<!--Keep This Empty / Menu will come through Javascript-->
								</ul>
							</div>
						</nav><!-- Main Menu End-->
		
						<!--Mobile Navigation Toggler-->
						<div class="mobile-nav-toggler"><span class="icon lnr-icon-bars"></span></div>
					</div>
				</div>
			</div>
		</div><!-- End Sticky Menu -->
	</header>
	<!--End Main Header -->

    <!-- MAIN SLIDER -->
    <section class="main-slider-v4">
        <div class="banner-slider-v4">
            <div class="banner-slide-v4">
                <div class="container">
                    <div class="banner-slide-content">
                        <div class="banner-content-column">
                            <span data-animation-in="fadeInUp" data-delay-in="0.1">action movie series</span>
                            <h2 class="title" data-animation-in="fadeInUp" data-delay-in="0.3">American Pickle</h2>
                            <ul class="banner-meta" data-animation-in="fadeInUp" data-delay-in="0.5">
                                <li><span class="rs">HD 1080</span></li>
                                <li class="time"><i class="fa fa-clock"></i> 1 hr 21 min</li>
                                <li class="like"><i class="fa fa-thumbs-up"></i> 68% liked this film</li>
                            </ul>
                            <p class="text" data-animation-in="fadeInUp" data-delay-in="0.7">Wherever you’re going on your entrepreneurial journey, we’re here to help you get there</p>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="btn-v4 swipebox" data-animation-in="fadeInUp" data-delay-in="0.9"><i class="fa fa-play"></i> Play video</a>
                        </div><!--banner-content-column-->
                        <div class="banner-image" data-animation-in="zoomIn" data-delay-in="0.5">
                            <img src="images/main-slider/image1.jpg" alt="">
                        </div>
                    </div>
                </div>
            </div><!--banner-slide-v4-->
            <div class="banner-slide-v4">
                <div class="container">
                    <div class="banner-slide-content">
                        <div class="banner-content-column">
                            <span data-animation-in="fadeInUp" data-delay-in="0.1">action movie series</span>
                            <h2 class="title" data-animation-in="fadeInUp" data-delay-in="0.3">American Pickle</h2>
                            <ul class="banner-meta" data-animation-in="fadeInUp" data-delay-in="0.5">
                                <li><span class="rs">HD 1080</span></li>
                                <li class="time"><i class="fa fa-clock"></i> 1 hr 21 min</li>
                                <li class="like"><i class="fa fa-thumbs-up"></i> 68% liked this film</li>
                            </ul>
                            <p class="text" data-animation-in="fadeInUp" data-delay-in="0.7">Wherever you’re going on your entrepreneurial journey, we’re here to help you get there</p>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="btn-v4 swipebox" data-animation-in="fadeInUp" data-delay-in="0.9"><i class="fa fa-play"></i> Play video</a>
                        </div><!--banner-content-column-->
                        <div class="banner-image" data-animation-in="zoomIn" data-delay-in="0.5">
                            <img src="images/main-slider/image1.jpg" alt="">
                        </div>
                    </div>
                </div>
            </div><!--banner-slide-v4-->
            <div class="banner-slide-v4">
                <div class="container">
                    <div class="banner-slide-content">
                        <div class="banner-content-column">
                            <span data-animation-in="fadeInUp" data-delay-in="0.1">action movie series</span>
                            <h2 class="title" data-animation-in="fadeInUp" data-delay-in="0.3">American Pickle</h2>
                            <ul class="banner-meta" data-animation-in="fadeInUp" data-delay-in="0.5">
                                <li><span class="rs">HD 1080</span></li>
                                <li class="time"><i class="fa fa-clock"></i> 1 hr 21 min</li>
                                <li class="like"><i class="fa fa-thumbs-up"></i> 68% liked this film</li>
                            </ul>
                            <p class="text" data-animation-in="fadeInUp" data-delay-in="0.7">Wherever you’re going on your entrepreneurial journey, we’re here to help you get there</p>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="btn-v4 swipebox" data-animation-in="fadeInUp" data-delay-in="0.9"><i class="fa fa-play"></i> Play video</a>
                        </div><!--banner-content-column-->
                        <div class="banner-image" data-animation-in="zoomIn" data-delay-in="0.5">
                            <img src="images/main-slider/image1.jpg" alt="">
                        </div>
                    </div>
                </div>
            </div><!--banner-slide-v4-->
        </div>
    </section>
    <!-- MAIN SLIDER END -->

    <!-- Categories section  -->
    <section class="categories-section">
        <div class="auto-container">
            <div class="content-box">
                <!-- Categories-block -->
                <div class="categories-block">
                    <div class="inner-box">
                        <figure class="image"><a href="page-movie.html"><img src="images/resource/Categories-1.png" alt=""></a></figure>
                        <h6 class="title">Action Movies</h6>
                    </div>
                </div>
                <!-- Categories-block -->
                <div class="categories-block">
                    <div class="inner-box">
                        <figure class="image"><a href="page-movie.html"><img src="images/resource/Categories-2.png" alt=""></a></figure>
                        <h6 class="title">Comedy Movies</h6>
                    </div>
                </div>
                <!-- Categories-block -->
                <div class="categories-block">
                    <div class="inner-box">
                        <figure class="image"><a href="page-movie.html"><img src="images/resource/Categories-3.png" alt=""></a></figure>
                        <h6 class="title">Fantasy Movies</h6>
                    </div>
                </div>
                <!-- Categories-block -->
                <div class="categories-block">
                    <div class="inner-box">
                        <figure class="image"><a href="page-movie.html"><img src="images/resource/Categories-4.png" alt=""></a></figure>
                        <h6 class="title">Horror Movies</h6>
                    </div>
                </div>
                <!-- Categories-block -->
                <div class="categories-block">
                    <div class="inner-box">
                        <figure class="image"><a href="page-movie.html"><img src="images/resource/Categories-5.png" alt=""></a></figure>
                        <h6 class="title">Romantic Movies</h6>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End Categories section -->

    <!-- About-section-three -->
    <section class="about-section-v3 pt-0">
        <div class="auto-container">
            <div class="row">
                <!-- content-column -->
                <div class="content-column col-lg-6 col-md-6 col-sm-12 wow fadeInLeft" data-wow-delay="400ms">
                    <div class="inner-column">
                        <div class="sec-title-v3">
                            <span class="sub-title">Free Streaming</span>
                            <h2>12 Days Free <br>Access to All Media <br>First Register !</h2>
                            <div class="text">Lorem ipsum dolor sit amet, consectetur adipis cng<br>elit, sed do eiusmod tempor incididunt ut la bore et<br>dolore magna aliqua Ut enim.
                            </div>
                        </div>
                        <ul class="list-style-five">
                            <li>Get TV Service with your Internet Service</li>
                            <li>Business is the activity of making one's living </li>
                            <li>Test Your Internet Speed</li>
                        </ul>
                    </div>
                </div>
                <!-- image column -->
                <div class="image-column col-lg-6 col-md-6 col-sm-12 wow fadeInRight" data-wow-delay="400ms">
                    <div class="inner-column">
                        <figure class="image"><a href="page-movie.html"><img src="images/resource/about3-1.png" alt=""></a></figure>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End about section three -->

    <!-- videos-section -->
    <section class="video-section pt-0">
        <div class="auto-container">
            <div class="sec-title-v3 text-center wow fadeInUp">
                <span class="sub-title">It's Time To Take Your Video</span>
                <h2>Recently Added</h2>
            </div>
            <div class="video-slider slider wow fadeInUp">
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-1.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The 400 Blows</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-2.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">La haine</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-3.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The Godfather</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-4.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The Bourne Identity</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-1.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The 400 Blows</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-2.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">La haine</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-3.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The Godfather</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-4.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The Bourne Identity</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                 <!-- video-block -->
                 <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-1.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The 400 Blows</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-2.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">La haine</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-3.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The Godfather</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-4.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The Bourne Identity</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-1.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The 400 Blows</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-2.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">La haine</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-3.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The Godfather</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <!-- video-block -->
                <div class="video-block">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/video-4.png" alt=""></a></figure>
                            <span class="time"><i class="fa fa-timer"></i>190 min</span>
                            <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox"><i class="icon fa fa-play"></i></a>
                        </div>
                        <div class="content-box">
                            <span>Comedy Drama</span>
                            <h6 class="title"><a href="page-movie.html">The Bourne Identity</a></h6>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#"><i class="fa fa-eye"></i>13K</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End video section -->

    <!-- What-we-do-section -->
    <section class="what-we-do-section">
        <div class="auto-container">
            <div class="row">
                <div class="content-column col-lg-5 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <div class="sec-title-v3 wow fadeInUp">
                            <span class="sub-title">What We Do</span>
                            <h2>Fast &amp; Reliable <br>Faster Network</h2>
                        </div>
                        <div class="image-box wow fadeInUp">
                            <figure class="image"><a href="#"><img src="images/resource/network-1.png" alt=""></a></figure>
                        </div>
                    </div>
                </div>
                <div class="col-lg-7 col-md-12 col-sm-12">
                    <div class="row">
                        <!-- What-we-do-section-block -->
                        <div class="what-we-do-block col-lg-6 col-md-12 col-sm-6">
                            <div class="inner-box wow fadeInUp">
                                <div class="icon-box"><i class="flaticon-satellite"></i></div>
                                <h6 class="title">Stream &amp; Record</h6>
                                <div class="text">Lorem ipsum dolor sit amet, con elit, sed do eiusmod tempor incid dolore magna aliqua.</div>
                            </div>
                        </div>
                        <!-- What-we-do-section-block -->
                        <div class="what-we-do-block col-lg-6 col-md-12 col-sm-6">
                            <div class="inner-box wow fadeInRight" data-wow-delay="200ms">
                                <div class="icon-box"><i class="flaticon-tv-monitor"></i></div>
                                <h6 class="title">200+ Movies</h6>
                                <div class="text">Lorem ipsum dolor sit amet, con
                                    elit, sed do eiusmod tempor incid
                                    dolore magna aliqua.</div>
                            </div>
                        </div>
                        <!-- What-we-do-section-block -->
                        <div class="what-we-do-block col-lg-6 col-md-12 col-sm-6">
                            <div class="inner-box wow fadeInUp" data-wow-delay="400ms">
                                <div class="icon-box"><i class="flaticon-services"></i></div>
                                <h6 class="title">Great Support</h6>
                                <div class="text">Lorem ipsum dolor sit amet, con
                                    elit, sed do eiusmod tempor incid
                                    dolore magna aliqua.</div>
                            </div>
                        </div>
                        <!-- What-we-do-section-block -->
                        <div class="what-we-do-block col-lg-6 col-md-12 col-sm-6">
                            <div class="inner-box wow fadeInRight" data-wow-delay="600ms">
                                <div class="icon-box"><i class="flaticon-upload"></i></div>
                                <h6 class="title">5G Internet Speed</h6>
                                <div class="text">Lorem ipsum dolor sit amet, con
                                    elit, sed do eiusmod tempor incid
                                    dolore magna aliqua.</div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End What-we-do-section -->

    <!-- Movies collection section -->
    <section class="movies-collection-section">
        <div class="auto-container">
            <div class="sec-title-v3 text-center wow fadeInUp">
                <span class="sub-title">It's Time To Take Your Vide</span>
                <h2>Our Movies Collection</h2>
            </div>
            <div class="row">
                <!-- movie-block -->
                <div class="movie-block col-lg-3 col-md-6 col-sm-6 wow fadeIn">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/movie-1.jpg" alt=""></a></figure>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#">13K</a></li>
                            </ul>
                        </div>
                        <div class="content-box">
                            <h6 class="title"><a href="page-movie.html">Wonder Woman 1984</a></h6>
                            <span>122 Min.<small>Year 2016</small></span>
                            <small class="trailer">JoBlo Movie Trailers<i class="icon fa fa-circle-check"></i></small>
                        </div>
                    </div>
                </div>
                <!-- movie-block -->
                <div class="movie-block col-lg-3 col-md-6 col-sm-6 wow fadeIn" data-wow-delay="100ms">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/movie-2.jpg" alt=""></a></figure>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#">13K</a></li>
                            </ul>
                        </div>
                        <div class="content-box">
                            <h6 class="title"><a href="page-movie.html">The Bourne Identity</a></h6>
                            <span>122 Min.<small>Year 2016</small></span>
                            <small class="trailer">JoBlo Movie Trailers<i class="icon fa fa-circle-check"></i></small>
                        </div>
                    </div>
                </div>
                <!-- movie-block -->
                <div class="movie-block col-lg-3 col-md-6 col-sm-6 wow fadeIn" data-wow-delay="200ms">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/movie-3.jpg" alt=""></a></figure>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#">13K</a></li>
                            </ul>
                        </div>
                        <div class="content-box">
                            <h6 class="title"><a href="page-movie.html">The Boondock Saints</a></h6>
                            <span>122 Min.<small>Year 2016</small></span>
                            <small class="trailer">JoBlo Movie Trailers<i class="icon fa fa-circle-check"></i></small>
                        </div>
                    </div>
                </div>
                <!-- movie-block -->
                <div class="movie-block col-lg-3 col-md-6 col-sm-6 wow fadeIn" data-wow-delay="300ms">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/movie-4.jpg" alt=""></a></figure>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#">13K</a></li>
                            </ul>
                        </div>
                        <div class="content-box">
                            <h6 class="title"><a href="page-movie.html">Blow</a></h6>
                            <span>122 Min.<small>Year 2016</small></span>
                            <small class="trailer">JoBlo Movie Trailers<i class="icon fa fa-circle-check"></i></small>
                        </div>
                    </div>
                </div>
                <!-- movie-block -->
                <div class="movie-block col-lg-3 col-md-6 col-sm-6 wow fadeIn" data-wow-delay="400ms">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/movie-5.jpg" alt=""></a></figure>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#">13K</a></li>
                            </ul>
                        </div>
                        <div class="content-box">
                            <h6 class="title"><a href="page-movie.html">Four Lions</a></h6>
                            <span>122 Min.<small>Year 2016</small></span>
                            <small class="trailer">JoBlo Movie Trailers<i class="icon fa fa-circle-check"></i></small>
                        </div>
                    </div>
                </div>
                <!-- movie-block -->
                <div class="movie-block col-lg-3 col-md-6 col-sm-6 wow fadeIn" data-wow-delay="500ms">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/movie-6.jpg" alt=""></a></figure>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#">13K</a></li>
                            </ul>
                        </div>
                        <div class="content-box">
                            <h6 class="title"><a href="page-movie.html">The Game</a></h6>
                            <span>122 Min.<small>Year 2016</small></span>
                            <small class="trailer">JoBlo Movie Trailers<i class="icon fa fa-circle-check"></i></small>
                        </div>
                    </div>
                </div>
                <!-- movie-block -->
                <div class="movie-block col-lg-3 col-md-6 col-sm-6 wow fadeIn" data-wow-delay="600ms">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/movie-7.jpg" alt=""></a></figure>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#">13K</a></li>
                            </ul>
                        </div>
                        <div class="content-box">
                            <h6 class="title"><a href="page-movie.html">Blood Diamond</a></h6>
                            <span>122 Min.<small>Year 2016</small></span>
                            <small class="trailer">JoBlo Movie Trailers<i class="icon fa fa-circle-check"></i></small>
                        </div>
                    </div>
                </div>
                <!-- movie-block -->
                <div class="movie-block col-lg-3 col-md-6 col-sm-6 wow fadeIn" data-wow-delay="700ms">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image"><a href="page-movie.html"><img src="images/resource/movie-8.jpg" alt=""></a></figure>
                            <ul class="views">
                                <li><a href="#">HD 1080</a></li>
                                <li><a href="#">13K</a></li>
                            </ul>
                        </div>
                        <div class="content-box">
                            <h6 class="title"><a href="page-movie.html">Tokyo Drift</a></h6>
                            <span>122 Min.<small>Year 2016</small></span>
                            <small class="trailer">JoBlo Movie Trailers<i class="icon fa fa-circle-check"></i></small>
                        </div>
                    </div>
                </div>
                <a href="page-movie.html" title="" class="read-more wow fadeInUp" data-wow-delay="800ms"><i class="fa-duotone fa-loader"></i>Load More</a>
            </div>
        </div>
    </section>
    <!-- End Movies-collection-section -->

    <!-- MOVIES TRAILERS -->
    <section class="movie-trailer-section">
        <div class="movie-trailer-slider">
            <div class="movie-trailer-slide">
                <div class="movie-trainer-image">
                    <img src="images/resource/large--img1.jpg" alt="">
                </div>
                <div class="movie-content">
                    <div class="container">
                        <div class="movie-trailer-slide-content">
                            <div class="movie-trailer-content-column">
                                <span data-animation-in="fadeInUp" data-delay-in="0.1">action movie series</span>
                                <h2 class="title" data-animation-in="fadeInUp" data-delay-in="0.2">Slumdog Millionaire</h2>
                                <ul class="banner-meta" data-animation-in="fadeInUp" data-delay-in="0.3">
                                    <li><span class="rs">HD 1080</span></li>
                                    <li class="time"><i class="fa fa-clock"></i> 1 hr 21 min</li>
                                </ul>
                                <a href="page-movie.html" title="" class="btn-v4" data-animation-in="fadeInUp" data-delay-in="0.4"><i class="fa fa-play"></i> Watch Trailer</a>
                            </div>
                            <div class="movie-play" data-animation-in="zoomIn" data-delay-in="0.5">
                                <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox" title=""><i class="fa fa-play"></i></a>
                            </div>
                        </div>
                    </div>
                </div>
            </div><!--movie-trailer-slide-->
            <div class="movie-trailer-slide">
                <div class="movie-trainer-image">
                    <img src="images/resource/large--img1.jpg" alt="">
                </div>
                <div class="movie-content">
                    <div class="container">
                        <div class="movie-trailer-slide-content">
                            <div class="movie-trailer-content-column">
                                <span data-animation-in="fadeInUp" data-delay-in="0.1">action movie series</span>
                                <h2 class="title" data-animation-in="fadeInUp" data-delay-in="0.2">Slumdog Millionaire</h2>
                                <ul class="banner-meta" data-animation-in="fadeInUp" data-delay-in="0.3">
                                    <li><span class="rs">HD 1080</span></li>
                                    <li class="time"><i class="fa fa-clock"></i> 1 hr 21 min</li>
                                </ul>
                                <a href="page-movie.html" title="" class="btn-v4" data-animation-in="fadeInUp" data-delay-in="0.4"><i class="fa fa-play"></i> Watch Trailer</a>
                            </div>
                            <div class="movie-play" data-animation-in="zoomIn" data-delay-in="0.5">
                                <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox" title=""><i class="fa fa-play"></i></a>
                            </div>
                        </div>
                    </div>
                </div>
            </div><!--movie-trailer-slide-->
            <div class="movie-trailer-slide">
                <div class="movie-trainer-image">
                    <img src="images/resource/large--img1.jpg" alt="">
                </div>
                <div class="movie-content">
                    <div class="container">
                        <div class="movie-trailer-slide-content">
                            <div class="movie-trailer-content-column">
                                <span data-animation-in="fadeInUp" data-delay-in="0.1">action movie series</span>
                                <h2 class="title" data-animation-in="fadeInUp" data-delay-in="0.2">Slumdog Millionaire</h2>
                                <ul class="banner-meta" data-animation-in="fadeInUp" data-delay-in="0.3">
                                    <li><span class="rs">HD 1080</span></li>
                                    <li class="time"><i class="fa fa-clock"></i> 1 hr 21 min</li>
                                </ul>
                                <a href="page-movie.html" title="" class="btn-v4" data-animation-in="fadeInUp" data-delay-in="0.4"><i class="fa fa-play"></i> Watch Trailer</a>
                            </div>
                            <div class="movie-play" data-animation-in="zoomIn" data-delay-in="0.5">
                                <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" class="swipebox" title=""><i class="fa fa-play"></i></a>
                            </div>
                        </div>
                    </div>
                </div>
            </div><!--movie-trailer-slide-->
        </div>
        <div class="movie-trailer-thumbs-slider">
            <div class="container">
                <div class="thumb-slider">
                    <div class="movie-thumb">
                        <img src="images/resource/th1.jpg" alt="">
                    </div>
                    <div class="movie-thumb">
                        <img src="images/resource/th2.jpg" alt="">
                    </div>
                    <div class="movie-thumb">
                        <img src="images/resource/th3.jpg" alt="">
                    </div>
                    <div class="movie-thumb">
                        <img src="images/resource/th4.jpg" alt="">
                    </div>
                </div>
            </div>
        </div><!--movie-trailer-thumbs-slider-->
    </section>
    <!-- MOVIES TRAILERS END -->

    <!-- pricing-plans-section -->
    <section class="pricing-plans-section pt-0">
        <div class="auto-container">
            <div class="sec-title-v3 text-center wow fadeInUp">
                <span class="sub-icon"></span>
                <span class="sub-title">It's Time To Take Your Video</span>
                <h2>Flexible Packages</h2>
            </div>
            <div class="row">
                <!-- pricing-block -->
                <div class="plan-block col-lg-4 col-md-6 col-sm-12 wow fadeIn">
                    <div class="plan-price">
                        <div class="info-box">
                            <h6 class="plan">Standard Plan</h6>
                            <h3 class="price"><span class="dolor">$</span>6.71</h3>
                            <small class="ticket">1 month membership</small>
                        </div>
                        <div class="plan-list">
                            <ul>
                                <li><i class="fa fa-check-circle"></i>Watch on your laptop</li>
                                <li><i class="fa fa-check-circle"></i>Watch on your mobile phone</li>
                                <li><i class="fa fa-check-circle"></i>HD video quality</li>
                                <li><i class="fa fa-check-circle"></i>Unlimited Downloads</li>
                            </ul>
                            <div class="btn-box">
                                <a href="page-contact.html" class="theme-btn btn-style-one"><span class="btn-title">Purchase Now</span></a>
                            </div>
                        </div>
                    </div>
                </div>
                <!-- pricing-block -->
                <div class="plan-block col-lg-4 col-md-6 col-sm-12 wow fadeIn" data-wow-delay="200ms">
                    <div class="plan-price">
                        <div class="info-box">
                            <h6 class="plan">Standard Plan</h6>
                            <h3 class="price"><span class="dolor">$</span>12.01</h3>
                            <small class="ticket">1 month membership</small>
                        </div>
                        <div class="plan-list">
                            <ul>
                                <li><i class="fa fa-check-circle"></i>Watch on your laptop</li>
                                <li><i class="fa fa-check-circle"></i>Watch on your mobile phone</li>
                                <li><i class="fa fa-check-circle"></i>HD video quality</li>
                                <li><i class="fa fa-check-circle"></i>Unlimited Downloads</li>
                            </ul>
                            <div class="btn-box">
                                <a href="page-contact.html" class="theme-btn btn-style-one"><span class="btn-title">Purchase Now</span></a>
                            </div>
                        </div>
                    </div>
                </div>
                <!-- pricing-block -->
                <div class="plan-block col-lg-4 col-md-6 col-sm-12 wow fadeIn" data-wow-delay="400ms">
                    <div class="plan-price">
                        <div class="info-box">
                            <h6 class="plan">Standard Plan</h6>
                            <h3 class="price"><span class="dolor">$</span>6.71</h3>
                            <small class="ticket">1 month membership</small>
                        </div>
                        <div class="plan-list">
                            <ul>
                                <li><i class="fa fa-check-circle"></i>Watch on your laptop</li>
                                <li><i class="fa fa-check-circle"></i>Watch on your mobile phone</li>
                                <li><i class="fa fa-check-circle"></i>HD video quality</li>
                                <li><i class="fa fa-check-circle"></i>Unlimited Downloads</li>
                            </ul>
                            <div class="btn-box">
                                <a href="page-contact.html" class="theme-btn btn-style-one"><span class="btn-title">Purchase Now</span></a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- end pricing-plans-section -->

    <!-- Testimonial Section -->
    <section class="testimonial-section-v3 pt-0">
        <div class="auto-container">            
            <div class="row">
                <div class="slider-column col-lg-7 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <div class="content-box">
                            <div class="sec-title-v3 wow fadeInUp">
                                <span class="sub-title">Testimonials</span>
                                <h2>Client’s Reviews</h2>
                            </div>
                            <div class="outer-box testimonial">
                                <div class="testimonial-slide">
                                    <div class="text" data-animation-in="fadeInUp" data-delay-in="0.1">“ As you know I run a small-ish video company
                                    in London. There are only 4 of us in the team 
                                    and we’re trying to compete with the big boys. 
                                    Your course has been a breath of fresh air! ” </div>
                                    <div class="auther-info" data-animation-in="fadeInUp" data-delay-in="0.2">
                                        <figure class="thumb"><img src="images/resource/test-thub3-1.png" alt=""></figure>
                                        <h6 class="title">Jorki Jannie</h6>
                                        <span class="designation">video company owner, london</span>
                                    </div>
                                </div>
                                <div class="testimonial-slide">
                                    <div class="text" data-animation-in="fadeInUp" data-delay-in="0.1">“ As you know I run a small-ish video company
                                    in London. There are only 4 of us in the team 
                                    and we’re trying to compete with the big boys. 
                                    Your course has been a breath of fresh air! ” </div>
                                    <div class="auther-info" data-animation-in="fadeInUp" data-delay-in="0.2">
                                        <figure class="thumb"><img src="images/resource/test-thub3-1.png" alt=""></figure>
                                        <h6 class="title">Jorki Jannie</h6>
                                        <span class="designation">video company owner, london</span>
                                    </div>
                                </div>
                                <div class="testimonial-slide">
                                    <div class="text" data-animation-in="fadeInUp" data-delay-in="0.1">“ As you know I run a small-ish video company
                                    in London. There are only 4 of us in the team 
                                    and we’re trying to compete with the big boys. 
                                    Your course has been a breath of fresh air! ” </div>
                                    <div class="auther-info" data-animation-in="fadeInUp" data-delay-in="0.2">
                                        <figure class="thumb"><img src="images/resource/test-thub3-1.png" alt=""></figure>
                                        <h6 class="title">Jorki Jannie</h6>
                                        <span class="designation">video company owner, london</span>
                                    </div>
                                </div>
                                <div class="testimonial-slide">
                                    <div class="text" data-animation-in="fadeInUp" data-delay-in="0.1">“ As you know I run a small-ish video company
                                    in London. There are only 4 of us in the team 
                                    and we’re trying to compete with the big boys. 
                                    Your course has been a breath of fresh air! ” </div>
                                    <div class="auther-info" data-animation-in="fadeInUp" data-delay-in="0.2">
                                        <figure class="thumb"><img src="images/resource/test-thub3-1.png" alt=""></figure>
                                        <h6 class="title">Jorki Jannie</h6>
                                        <span class="designation">video company owner, london</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="image-column col-lg-5 col-md-12 col-sm-12">
                    <div class="inner-column wow zoomIn">
                        <figure class="image"><img src="images/resource/testi-img2.png" alt=""></figure>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End Testimonial Section -->

    <!-- movie-categories-section -->
    <section class="movie-categories-section p-0">
        <div class="bg bg-backround"></div>
        <div class="auto-container">
            <div class="content-box">
                <div class="sec-title-v3 text-center wow fadeInUp">
                    <span class="sub-title">Watch anywhere. Cancel anytime.</span>
                    <h2>Unlimited Movies, TV Dramas <br>Shows, and More.</h2>
                </div>
                <div class="info-box wow fadeInUp" data-wow-delay="200ms">
                    <a href="#" class="btn-box">
                        <i class="icon fa fa-play"></i>
                        <span>Download From</span>
                        <h6 class="title">Google Play</h6>
                    </a>
                    <a href="#" class="btn-box-two">
                        <i class="icon fa-brands fa-apple"></i>
                        <span>Download From</span>
                        <h6 class="title">Google Play</h6>
                    </a>
                </div>
            </div>
            <div class="image-box wow fadeInUp" data-wow-delay="400ms">
                <img src="images/resource/movie-img.png" alt="">
            </div>
        </div>
    </section>
    <!-- End movie-categories-section -->

    <!-- client-section -->
    <section class="client-section">
        <div class="auto-container">
            <div class="content-box client-slider">
                <div class="image-box wow fadeIn">
                    <figure class="image"><img src="images/resource/client-1.png" alt=""></figure>
                </div>
                <div class="image-box wow fadeIn" data-wow-delay="100ms">
                    <figure class="image"><img src="images/resource/client-2.png" alt=""></figure>
                </div>
                <div class="image-box wow fadeIn" data-wow-delay="200ms">
                    <figure class="image"><img src="images/resource/client-3.png" alt=""></figure>
                </div>
                <div class="image-box wow fadeIn" data-wow-delay="300ms">
                    <figure class="image"><img src="images/resource/client-4.png" alt=""></figure>
                </div>
                <div class="image-box wow fadeIn" data-wow-delay="400ms">
                    <figure class="image"><img src="images/resource/client-5.png" alt=""></figure>
                </div>
                <div class="image-box wow fadeIn" data-wow-delay="500ms">
                    <figure class="image"><img src="images/resource/client-1.png" alt=""></figure>
                </div>
                <div class="image-box wow fadeIn" data-wow-delay="600ms">
                    <figure class="image"><img src="images/resource/client-2.png" alt=""></figure>
                </div>
                <div class="image-box wow fadeIn" data-wow-delay="700ms">
                    <figure class="image"><img src="images/resource/client-3.png" alt=""></figure>
                </div>
                <div class="image-box wow fadeIn" data-wow-delay="800ms">
                    <figure class="image"><img src="images/resource/client-4.png" alt=""></figure>
                </div>
                <div class="image-box wow fadeIn" data-wow-delay="900ms">
                    <figure class="image"><img src="images/resource/client-5.png" alt=""></figure>
                </div>
            </div>
        </div>
    </section>
    <!-- End client section --> 

    <footer class="footer-v3">
        <div class="container">
            <div class="widgets-sections row">
                <div class="col-lg-6 col-md-12 footer-column">
                    <div class="widget widget-newsletter wow fadeInLeft">
                        <img src="images/logo-v3.png" alt="">
                        <p>Ready to watch? Enter your email to create or restart <br>your membership.</p>
                        <form>
                            <input type="text" name="email" placeholder="Enter your email address...">
                            <button type="submit">Subscribe</button>
                        </form>
                    </div><!--widget-newsletter-->
                </div>
                <div class="col-lg-3 col-md-6 footer-column">
                    <div class="widget widget-links wow fadeInUp" data-wow-delay="200ms">
                        <h4 class="widget-title">My Account</h4>
                        <ul class="user-links">
                            <li><a href="#" title="">FAQ</a></li>
                            <li><a href="#" title="">Help Center</a></li>
                            <li><a href="#" title="">Media Center</a></li>
                            <li><a href="#" title="">Services</a></li>
                            <li><a href="#" title="">Investor Relations</a></li>
                        </ul>
                    </div><!--widget-links end-->
                </div>
                <div class="col-lg-3 col-md-6 footer-column">
                    <div class="widget widget-links wow fadeInRight" data-wow-delay="400ms">
                        <h4 class="widget-title">Useful Links</h4>
                        <ul class="user-links">
                            <li><a href="#" title="">Online Video Platform</a></li>
                            <li><a href="#" title="">TV Everywhere Platform</a></li>
                            <li><a href="#" title="">Features</a></li>
                            <li><a href="#" title="">Tour</a></li>
                            <li><a href="#" title="">How does it work?</a></li>
                        </ul>
                    </div><!--widget-links end-->
                </div>
            </div>
        </div>
        <div class="footer-bottom">
            <div class="container">
                <div class="outer-box">
                    <div class="contact-info row">
                        <!-- Contact-block -->
                        <div class="contact-block col-lg-4 col-md-6 col-sm-12">
                            <div class="inner-box">
                                <i class="icon fa fa-phone"></i>
                                <span>Phone No:</span>
                                <small>+88(9800) 6802</small>
                            </div>
                        </div>
                        <!-- Contact-block -->
                        <div class="contact-block col-lg-4 col-md-6 col-sm-12">
                            <div class="inner-box">
                                <i class="icon fa fa-envelope"></i>
                                <span>Email Address:</span>
                                <small><a href="https://html.kodesolution.com/cdn-cgi/l/email-protection" class="__cf_email__" data-cfemail="f1848294839f909c94b1959e9c90989fdf929e9c">[email&nbsp;protected]</a></small>
                            </div>
                        </div>
                        <!-- Contact-block -->
                        <div class="contact-block col-lg-4 col-md-6 col-sm-12">
                            <div class="inner-box">
                                <i class="icon fa fa-location"></i>
                                <span>503 Old Buffalo Street</span>
                                <small>Northwest #205, New York-3087</small>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row align-items-center">
                    <div class="col-lg-5 col-md-12 col-sm-12 copyright-text">
                        <p>Copyright © reserved by . koresolution.</p>
                    </div>
                    <div class="col-lg-3 col-md-12 col-sm-12 social-column">
                        <ul class="social-links">
                            <li><a href="#" title=""><i class="fab fa-facebook-square"></i></a></li>
                            <li><a href="#" title=""><i class="fab fa-google-plus-g"></i></a></li>
                            <li><a href="#" title=""><i class="fa fa-x"></i></a></li>
                        </ul>
                    </div>
                    <div class="col-lg-4 col-md-12 col-sm-12 links-column">
                        <ul class="other-links">
                            <li><a href="#" title="">About</a></li>
                            <li><a href="#" title="">Terms</a></li>
                            <li><a href="#" title="">privacy policy</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </footer>


</div>
    <!-- Scroll To Top -->
<div class="scroll-to-top scroll-to-target clr-v2" data-target="html"><span class="fa fa-angle-up"></span></div>

<script data-cfasync="false" src="../../cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.js"></script><script src="js/jquery.js"></script> 
<script src="js/jquery-migrate-1.4.1.min.js"></script>
<script src="js/slick.min.js"></script>
<script src="js/popper.min.js"></script>
<script src="js/bootstrap.min.js"></script>
<script src="js/slick-animation.min.js"></script>
<script src="js/wow.js"></script>
<script src="js/select2.min.js"></script>
<script src="js/jquery.swipebox.min.js"></script>
<script src="js/swiper-bundle.min.js"></script>
<script src="js/script.js"></script>




<script id="custom-js" src="js/code_editor_scripts.js?p2o5Kifo"></script></body><!-- Mirrored from html.kodesolution.com/2023/satnet-html/index-3.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:14:24 GMT --></html>